app

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package app provides the root command for the medic CLI

Index

Constants

const JSON = "json"

JSON is the json format for output

const Table = "table"

Table is the table format for output

const YAML = "yaml"

YAML is the yaml format for output

Variables

var (

	// RootCmd represents the base command when called without any subcommands
	RootCmd = &cobra.Command{
		Use:   "medic",
		Short: "medic controls mediator via the control plane",
		Long: `For more information about mediator, please visit:
https://docs.stacklok.com/mediator/medic/overview.html`,
	}
)

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

This section is empty.

Directories

Path Synopsis
Package apply provides the apply command for the medic CLI
Package apply provides the apply command for the medic CLI
Package artifact provides the artifact subcommands
Package artifact provides the artifact subcommands
Package auth provides the auth command project for the medic CLI.
Package auth provides the auth command project for the medic CLI.
Package apply provides the apply command for the medic CLI
Package apply provides the apply command for the medic CLI
Package keys provides the cli subcommands for managing keys within a mediator control plane
Package keys provides the cli subcommands for managing keys within a mediator control plane
Package org contains the organization logic for the control plane
Package org contains the organization logic for the control plane
Package profile provides the CLI subcommand for managing profiles
Package profile provides the CLI subcommand for managing profiles
Package profile_status provides the CLI subcommand for managing profile statuses
Package profile_status provides the CLI subcommand for managing profile statuses
Package project contains the project logic for the control plane
Package project contains the project logic for the control plane
Package provider is the root command for the provider subcommands
Package provider is the root command for the provider subcommands
Package repo contains the repo logic for the control plane
Package repo contains the repo logic for the control plane
Package role provides the cli subcommands for managing roles within a mediator control plane
Package role provides the cli subcommands for managing roles within a mediator control plane
Package rule_type provides the CLI subcommand for managing rules
Package rule_type provides the CLI subcommand for managing rules
Package user provides the user subcommand for the medic CLI.
Package user provides the user subcommand for the medic CLI.

Jump to