provider

package
v0.0.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 3, 2023 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Overview

Package provider is the root command for the provider subcommands

Index

Constants

const MAX_CALLS = 300

MAX_CALLS is the maximum number of calls to the gRPC server before stopping.

Variables

var ProviderCmd = &cobra.Command{
	Use:   "provider",
	Short: "Manage providers within a minder control plane",
	Long:  `The minder provider commands manage providers within a minder control plane.`,
	RunE: func(cmd *cobra.Command, args []string) error {
		return cmd.Usage()
	},
}

ProviderCmd is the root command for the provider subcommands

Functions

This section is empty.

Types

type Response

type Response struct {
	Status string `json:"status"`
}

Response is the response from the OAuth callback server.

Jump to