Documentation
¶
Index ¶
- func CalculateProjectHierarchyOffset(hierarchy int) int
- type ActionType
- type AddUserProjectParams
- type AddUserRoleParams
- type AlertStatusTypes
- type Artifact
- type ArtifactVersion
- type CreateAccessTokenParams
- type CreateArtifactParams
- type CreateArtifactVersionParams
- type CreateOrganizationParams
- type CreateProfileForEntityParams
- type CreateProfileParams
- type CreateProjectParams
- type CreateProviderParams
- type CreateRepositoryParams
- type CreateRoleParams
- type CreateRuleTypeParams
- type CreateSessionStateParams
- type CreateSigningKeyParams
- type CreateUserParams
- type DBTX
- type DeleteAccessTokenParams
- type DeleteOldArtifactVersionsParams
- type DeleteProjectRow
- type DeleteProviderParams
- type DeleteSessionStateByProjectIDParams
- type DeleteSigningKeyParams
- type Entities
- type EntityProfile
- type EntityProfileRule
- type EvalStatusTypes
- type GetAccessTokenByProjectIDParams
- type GetAccessTokenSinceDateParams
- type GetArtifactByIDRow
- type GetChildrenProjectsRow
- type GetParentProjectsUntilParams
- type GetProfileByProjectAndIDParams
- type GetProfileByProjectAndIDRow
- type GetProfileByProjectAndNameParams
- type GetProfileByProjectAndNameRow
- type GetProfileStatusByIdAndProjectParams
- type GetProfileStatusByIdAndProjectRow
- type GetProfileStatusByNameAndProjectParams
- type GetProfileStatusByNameAndProjectRow
- type GetProfileStatusByProjectRow
- type GetProjectIDPortBySessionStateRow
- type GetProviderByIDParams
- type GetProviderByNameParams
- type GetRepositoryByIDAndProjectParams
- type GetRepositoryByRepoNameParams
- type GetRoleByNameParams
- type GetRuleTypeByNameParams
- type GetUserProjectsRow
- type GetUserRolesRow
- type ListArtifactVersionsByArtifactIDAndTagParams
- type ListArtifactVersionsByArtifactIDParams
- type ListOrganizationsParams
- type ListProfilesByProjectIDRow
- type ListProfilesInstantiatingRuleTypeRow
- type ListRegisteredRepositoriesByProjectIDAndProviderParams
- type ListRepositoriesByOwnerParams
- type ListRepositoriesByProjectIDParams
- type ListRolesByProjectIDParams
- type ListRolesParams
- type ListRuleEvaluationsByProfileIdParams
- type ListRuleEvaluationsByProfileIdRow
- type ListRuleTypesByProviderAndProjectParams
- type ListUsersByOrganizationParams
- type ListUsersByProjectParams
- type ListUsersParams
- type NullActionType
- type NullAlertStatusTypes
- type NullEntities
- type NullEvalStatusTypes
- type NullProviderType
- type NullRemediationStatusTypes
- type Profile
- type ProfileStatus
- type Project
- type Provider
- type ProviderAccessToken
- type ProviderType
- type Querier
- type Queries
- func (q *Queries) AddUserProject(ctx context.Context, arg AddUserProjectParams) (UserProject, error)
- func (q *Queries) AddUserRole(ctx context.Context, arg AddUserRoleParams) (UserRole, error)
- func (q *Queries) CreateAccessToken(ctx context.Context, arg CreateAccessTokenParams) (ProviderAccessToken, error)
- func (q *Queries) CreateArtifact(ctx context.Context, arg CreateArtifactParams) (Artifact, error)
- func (q *Queries) CreateArtifactVersion(ctx context.Context, arg CreateArtifactVersionParams) (ArtifactVersion, error)
- func (q *Queries) CreateOrganization(ctx context.Context, arg CreateOrganizationParams) (Project, error)
- func (q *Queries) CreateProfile(ctx context.Context, arg CreateProfileParams) (Profile, error)
- func (q *Queries) CreateProfileForEntity(ctx context.Context, arg CreateProfileForEntityParams) (EntityProfile, error)
- func (q *Queries) CreateProject(ctx context.Context, arg CreateProjectParams) (Project, error)
- func (q *Queries) CreateProvider(ctx context.Context, arg CreateProviderParams) (Provider, error)
- func (q *Queries) CreateRepository(ctx context.Context, arg CreateRepositoryParams) (Repository, error)
- func (q *Queries) CreateRole(ctx context.Context, arg CreateRoleParams) (Role, error)
- func (q *Queries) CreateRuleType(ctx context.Context, arg CreateRuleTypeParams) (RuleType, error)
- func (q *Queries) CreateSessionState(ctx context.Context, arg CreateSessionStateParams) (SessionStore, error)
- func (q *Queries) CreateSigningKey(ctx context.Context, arg CreateSigningKeyParams) (SigningKey, error)
- func (q *Queries) CreateUser(ctx context.Context, arg CreateUserParams) (User, error)
- func (q *Queries) DeleteAccessToken(ctx context.Context, arg DeleteAccessTokenParams) error
- func (q *Queries) DeleteArtifact(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteArtifactVersion(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteExpiredSessionStates(ctx context.Context) error
- func (q *Queries) DeleteOldArtifactVersions(ctx context.Context, arg DeleteOldArtifactVersionsParams) error
- func (q *Queries) DeleteOrganization(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteProfile(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteProject(ctx context.Context, id uuid.UUID) ([]DeleteProjectRow, error)
- func (q *Queries) DeleteProvider(ctx context.Context, arg DeleteProviderParams) error
- func (q *Queries) DeleteRepository(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteRole(ctx context.Context, id int32) error
- func (q *Queries) DeleteRuleType(ctx context.Context, id uuid.UUID) error
- func (q *Queries) DeleteSessionState(ctx context.Context, id int32) error
- func (q *Queries) DeleteSessionStateByProjectID(ctx context.Context, arg DeleteSessionStateByProjectIDParams) error
- func (q *Queries) DeleteSigningKey(ctx context.Context, arg DeleteSigningKeyParams) error
- func (q *Queries) DeleteUser(ctx context.Context, id int32) error
- func (q *Queries) GetAccessTokenByProjectID(ctx context.Context, arg GetAccessTokenByProjectIDParams) (ProviderAccessToken, error)
- func (q *Queries) GetAccessTokenByProvider(ctx context.Context, provider string) ([]ProviderAccessToken, error)
- func (q *Queries) GetAccessTokenSinceDate(ctx context.Context, arg GetAccessTokenSinceDateParams) (ProviderAccessToken, error)
- func (q *Queries) GetArtifactByID(ctx context.Context, id uuid.UUID) (GetArtifactByIDRow, error)
- func (q *Queries) GetArtifactVersionByID(ctx context.Context, id uuid.UUID) (ArtifactVersion, error)
- func (q *Queries) GetArtifactVersionBySha(ctx context.Context, sha string) (ArtifactVersion, error)
- func (q *Queries) GetChildrenProjects(ctx context.Context, id uuid.UUID) ([]GetChildrenProjectsRow, error)
- func (q *Queries) GetOrganization(ctx context.Context, id uuid.UUID) (Project, error)
- func (q *Queries) GetOrganizationByName(ctx context.Context, name string) (Project, error)
- func (q *Queries) GetOrganizationForUpdate(ctx context.Context, name string) (Project, error)
- func (q *Queries) GetParentProjects(ctx context.Context, id uuid.UUID) ([]uuid.UUID, error)
- func (q *Queries) GetParentProjectsUntil(ctx context.Context, arg GetParentProjectsUntilParams) ([]uuid.UUID, error)
- func (q *Queries) GetProfileByID(ctx context.Context, id uuid.UUID) (Profile, error)
- func (q *Queries) GetProfileByProjectAndID(ctx context.Context, arg GetProfileByProjectAndIDParams) ([]GetProfileByProjectAndIDRow, error)
- func (q *Queries) GetProfileByProjectAndName(ctx context.Context, arg GetProfileByProjectAndNameParams) ([]GetProfileByProjectAndNameRow, error)
- func (q *Queries) GetProfileStatusByIdAndProject(ctx context.Context, arg GetProfileStatusByIdAndProjectParams) (GetProfileStatusByIdAndProjectRow, error)
- func (q *Queries) GetProfileStatusByNameAndProject(ctx context.Context, arg GetProfileStatusByNameAndProjectParams) (GetProfileStatusByNameAndProjectRow, error)
- func (q *Queries) GetProfileStatusByProject(ctx context.Context, projectID uuid.UUID) ([]GetProfileStatusByProjectRow, error)
- func (q *Queries) GetProjectByID(ctx context.Context, id uuid.UUID) (Project, error)
- func (q *Queries) GetProjectByName(ctx context.Context, name string) (Project, error)
- func (q *Queries) GetProjectIDPortBySessionState(ctx context.Context, sessionState string) (GetProjectIDPortBySessionStateRow, error)
- func (q *Queries) GetProviderByID(ctx context.Context, arg GetProviderByIDParams) (Provider, error)
- func (q *Queries) GetProviderByName(ctx context.Context, arg GetProviderByNameParams) (Provider, error)
- func (q *Queries) GetRepositoryByID(ctx context.Context, id uuid.UUID) (Repository, error)
- func (q *Queries) GetRepositoryByIDAndProject(ctx context.Context, arg GetRepositoryByIDAndProjectParams) (Repository, error)
- func (q *Queries) GetRepositoryByRepoID(ctx context.Context, repoID int32) (Repository, error)
- func (q *Queries) GetRepositoryByRepoName(ctx context.Context, arg GetRepositoryByRepoNameParams) (Repository, error)
- func (q *Queries) GetRoleByID(ctx context.Context, id int32) (Role, error)
- func (q *Queries) GetRoleByName(ctx context.Context, arg GetRoleByNameParams) (Role, error)
- func (q *Queries) GetRootProjects(ctx context.Context) ([]Project, error)
- func (q *Queries) GetRuleTypeByID(ctx context.Context, id uuid.UUID) (RuleType, error)
- func (q *Queries) GetRuleTypeByName(ctx context.Context, arg GetRuleTypeByNameParams) (RuleType, error)
- func (q *Queries) GetSessionState(ctx context.Context, id int32) (SessionStore, error)
- func (q *Queries) GetSessionStateByProjectID(ctx context.Context, projectID uuid.UUID) (SessionStore, error)
- func (q *Queries) GetSigningKeyByIdentifier(ctx context.Context, keyIdentifier string) (SigningKey, error)
- func (q *Queries) GetSigningKeyByProjectID(ctx context.Context, projectID uuid.UUID) (SigningKey, error)
- func (q *Queries) GetUserByID(ctx context.Context, id int32) (User, error)
- func (q *Queries) GetUserBySubject(ctx context.Context, identitySubject string) (User, error)
- func (q *Queries) GetUserProjects(ctx context.Context, userID int32) ([]GetUserProjectsRow, error)
- func (q *Queries) GetUserRoles(ctx context.Context, userID int32) ([]GetUserRolesRow, error)
- func (q *Queries) GlobalListProviders(ctx context.Context) ([]Provider, error)
- func (q *Queries) ListAllRepositories(ctx context.Context, provider string) ([]Repository, error)
- func (q *Queries) ListArtifactVersionsByArtifactID(ctx context.Context, arg ListArtifactVersionsByArtifactIDParams) ([]ArtifactVersion, error)
- func (q *Queries) ListArtifactVersionsByArtifactIDAndTag(ctx context.Context, arg ListArtifactVersionsByArtifactIDAndTagParams) ([]ArtifactVersion, error)
- func (q *Queries) ListArtifactsByRepoID(ctx context.Context, repositoryID uuid.UUID) ([]Artifact, error)
- func (q *Queries) ListOrganizations(ctx context.Context, arg ListOrganizationsParams) ([]Project, error)
- func (q *Queries) ListProfilesByProjectID(ctx context.Context, projectID uuid.UUID) ([]ListProfilesByProjectIDRow, error)
- func (q *Queries) ListProfilesInstantiatingRuleType(ctx context.Context, ruleTypeID uuid.UUID) ([]ListProfilesInstantiatingRuleTypeRow, error)
- func (q *Queries) ListProvidersByProjectID(ctx context.Context, projectID uuid.UUID) ([]Provider, error)
- func (q *Queries) ListRegisteredRepositoriesByProjectIDAndProvider(ctx context.Context, ...) ([]Repository, error)
- func (q *Queries) ListRepositoriesByOwner(ctx context.Context, arg ListRepositoriesByOwnerParams) ([]Repository, error)
- func (q *Queries) ListRepositoriesByProjectID(ctx context.Context, arg ListRepositoriesByProjectIDParams) ([]Repository, error)
- func (q *Queries) ListRoles(ctx context.Context, arg ListRolesParams) ([]Role, error)
- func (q *Queries) ListRolesByProjectID(ctx context.Context, arg ListRolesByProjectIDParams) ([]Role, error)
- func (q *Queries) ListRuleEvaluationsByProfileId(ctx context.Context, arg ListRuleEvaluationsByProfileIdParams) ([]ListRuleEvaluationsByProfileIdRow, error)
- func (q *Queries) ListRuleTypesByProviderAndProject(ctx context.Context, arg ListRuleTypesByProviderAndProjectParams) ([]RuleType, error)
- func (q *Queries) ListUsers(ctx context.Context, arg ListUsersParams) ([]User, error)
- func (q *Queries) ListUsersByOrganization(ctx context.Context, arg ListUsersByOrganizationParams) ([]User, error)
- func (q *Queries) ListUsersByProject(ctx context.Context, arg ListUsersByProjectParams) ([]User, error)
- func (q *Queries) ListUsersByRoleId(ctx context.Context, roleID int32) ([]int32, error)
- func (q *Queries) UpdateAccessToken(ctx context.Context, arg UpdateAccessTokenParams) (ProviderAccessToken, error)
- func (q *Queries) UpdateOrganization(ctx context.Context, arg UpdateOrganizationParams) (Project, error)
- func (q *Queries) UpdateRepository(ctx context.Context, arg UpdateRepositoryParams) (Repository, error)
- func (q *Queries) UpdateRepositoryByID(ctx context.Context, arg UpdateRepositoryByIDParams) (Repository, error)
- func (q *Queries) UpdateRole(ctx context.Context, arg UpdateRoleParams) (Role, error)
- func (q *Queries) UpdateRuleType(ctx context.Context, arg UpdateRuleTypeParams) error
- func (q *Queries) UpsertArtifact(ctx context.Context, arg UpsertArtifactParams) (Artifact, error)
- func (q *Queries) UpsertArtifactVersion(ctx context.Context, arg UpsertArtifactVersionParams) (ArtifactVersion, error)
- func (q *Queries) UpsertRuleDetailsAlert(ctx context.Context, arg UpsertRuleDetailsAlertParams) (uuid.UUID, error)
- func (q *Queries) UpsertRuleDetailsEval(ctx context.Context, arg UpsertRuleDetailsEvalParams) (uuid.UUID, error)
- func (q *Queries) UpsertRuleDetailsRemediate(ctx context.Context, arg UpsertRuleDetailsRemediateParams) (uuid.UUID, error)
- func (q *Queries) UpsertRuleEvaluations(ctx context.Context, arg UpsertRuleEvaluationsParams) (uuid.UUID, error)
- func (q *Queries) UpsertRuleInstantiation(ctx context.Context, arg UpsertRuleInstantiationParams) (EntityProfileRule, error)
- func (q *Queries) WithTx(tx *sql.Tx) *Queries
- type RemediationStatusTypes
- type Repository
- type Role
- type RuleDetailsAlert
- type RuleDetailsEval
- type RuleDetailsRemediate
- type RuleEvaluation
- type RuleType
- type SQLStore
- type SessionStore
- type SigningKey
- type Store
- type UpdateAccessTokenParams
- type UpdateOrganizationParams
- type UpdateRepositoryByIDParams
- type UpdateRepositoryParams
- type UpdateRoleParams
- type UpdateRuleTypeParams
- type UpsertArtifactParams
- type UpsertArtifactVersionParams
- type UpsertRuleDetailsAlertParams
- type UpsertRuleDetailsEvalParams
- type UpsertRuleDetailsRemediateParams
- type UpsertRuleEvaluationsParams
- type UpsertRuleInstantiationParams
- type User
- type UserProject
- type UserRole
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateProjectHierarchyOffset ¶ added in v0.0.5
CalculateProjectHierarchyOffset will calculate the offset for the hierarchy in the returned array from GetChildrenProjects and GetParentProjects. This is because the calling project is also returned.
Types ¶
type ActionType ¶ added in v0.0.7
type ActionType string
const ( ActionTypeOn ActionType = "on" ActionTypeOff ActionType = "off" ActionTypeDryRun ActionType = "dry_run" )
func (*ActionType) Scan ¶ added in v0.0.7
func (e *ActionType) Scan(src interface{}) error
type AddUserProjectParams ¶ added in v0.0.5
type AddUserRoleParams ¶
type AlertStatusTypes ¶ added in v0.0.7
type AlertStatusTypes string
const ( AlertStatusTypesOn AlertStatusTypes = "on" AlertStatusTypesOff AlertStatusTypes = "off" AlertStatusTypesError AlertStatusTypes = "error" AlertStatusTypesSkipped AlertStatusTypes = "skipped" AlertStatusTypesNotAvailable AlertStatusTypes = "not_available" )
func (*AlertStatusTypes) Scan ¶ added in v0.0.7
func (e *AlertStatusTypes) Scan(src interface{}) error
type Artifact ¶
type Artifact struct {
ID uuid.UUID `json:"id"`
RepositoryID uuid.UUID `json:"repository_id"`
ArtifactName string `json:"artifact_name"`
ArtifactType string `json:"artifact_type"`
ArtifactVisibility string `json:"artifact_visibility"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type ArtifactVersion ¶
type ArtifactVersion struct {
ID uuid.UUID `json:"id"`
ArtifactID uuid.UUID `json:"artifact_id"`
Version int64 `json:"version"`
Tags sql.NullString `json:"tags"`
Sha string `json:"sha"`
SignatureVerification pqtype.NullRawMessage `json:"signature_verification"`
GithubWorkflow pqtype.NullRawMessage `json:"github_workflow"`
CreatedAt time.Time `json:"created_at"`
}
type CreateAccessTokenParams ¶
type CreateArtifactParams ¶
type CreateArtifactVersionParams ¶
type CreateArtifactVersionParams struct {
ArtifactID uuid.UUID `json:"artifact_id"`
Version int64 `json:"version"`
Tags sql.NullString `json:"tags"`
Sha string `json:"sha"`
CreatedAt time.Time `json:"created_at"`
SignatureVerification json.RawMessage `json:"signature_verification"`
GithubWorkflow json.RawMessage `json:"github_workflow"`
}
type CreateOrganizationParams ¶
type CreateOrganizationParams struct {
Name string `json:"name"`
Metadata json.RawMessage `json:"metadata"`
}
type CreateProfileForEntityParams ¶ added in v0.0.6
type CreateProfileForEntityParams struct {
Entity Entities `json:"entity"`
ProfileID uuid.UUID `json:"profile_id"`
ContextualRules json.RawMessage `json:"contextual_rules"`
}
type CreateProfileParams ¶ added in v0.0.6
type CreateProfileParams struct {
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Remediate NullActionType `json:"remediate"`
Alert NullActionType `json:"alert"`
Name string `json:"name"`
}
type CreateProjectParams ¶
type CreateProjectParams struct {
Name string `json:"name"`
ParentID uuid.NullUUID `json:"parent_id"`
Metadata json.RawMessage `json:"metadata"`
}
type CreateProviderParams ¶ added in v0.0.4
type CreateProviderParams struct {
Name string `json:"name"`
ProjectID uuid.UUID `json:"project_id"`
Implements []ProviderType `json:"implements"`
Definition json.RawMessage `json:"definition"`
}
type CreateRepositoryParams ¶
type CreateRepositoryParams struct {
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
RepoOwner string `json:"repo_owner"`
RepoName string `json:"repo_name"`
RepoID int32 `json:"repo_id"`
IsPrivate bool `json:"is_private"`
IsFork bool `json:"is_fork"`
WebhookID sql.NullInt32 `json:"webhook_id"`
WebhookUrl string `json:"webhook_url"`
DeployUrl string `json:"deploy_url"`
CloneUrl string `json:"clone_url"`
}
type CreateRoleParams ¶
type CreateRuleTypeParams ¶
type CreateSigningKeyParams ¶
type CreateUserParams ¶
type CreateUserParams struct {
OrganizationID uuid.UUID `json:"organization_id"`
Email sql.NullString `json:"email"`
IdentitySubject string `json:"identity_subject"`
FirstName sql.NullString `json:"first_name"`
LastName sql.NullString `json:"last_name"`
}
type DeleteAccessTokenParams ¶
type DeleteProjectRow ¶
type DeleteProviderParams ¶ added in v0.0.4
type DeleteSessionStateByProjectIDParams ¶ added in v0.0.5
type DeleteSigningKeyParams ¶
type EntityProfile ¶ added in v0.0.6
type EntityProfileRule ¶ added in v0.0.7
type EvalStatusTypes ¶
type EvalStatusTypes string
const ( EvalStatusTypesSuccess EvalStatusTypes = "success" EvalStatusTypesFailure EvalStatusTypes = "failure" EvalStatusTypesError EvalStatusTypes = "error" EvalStatusTypesSkipped EvalStatusTypes = "skipped" EvalStatusTypesPending EvalStatusTypes = "pending" )
func (*EvalStatusTypes) Scan ¶
func (e *EvalStatusTypes) Scan(src interface{}) error
type GetAccessTokenByProjectIDParams ¶ added in v0.0.5
type GetArtifactByIDRow ¶
type GetArtifactByIDRow struct {
ID uuid.UUID `json:"id"`
RepositoryID uuid.UUID `json:"repository_id"`
ArtifactName string `json:"artifact_name"`
ArtifactType string `json:"artifact_type"`
ArtifactVisibility string `json:"artifact_visibility"`
CreatedAt time.Time `json:"created_at"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
RepoOwner string `json:"repo_owner"`
RepoName string `json:"repo_name"`
}
type GetChildrenProjectsRow ¶ added in v0.0.5
type GetProfileByProjectAndIDParams ¶ added in v0.0.6
type GetProfileByProjectAndIDRow ¶ added in v0.0.6
type GetProfileByProjectAndIDRow struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Remediate NullActionType `json:"remediate"`
Alert NullActionType `json:"alert"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
ID_2 uuid.UUID `json:"id_2"`
Entity Entities `json:"entity"`
ProfileID uuid.UUID `json:"profile_id"`
ContextualRules json.RawMessage `json:"contextual_rules"`
CreatedAt_2 time.Time `json:"created_at_2"`
UpdatedAt_2 time.Time `json:"updated_at_2"`
}
type GetProfileByProjectAndNameParams ¶ added in v0.0.6
type GetProfileByProjectAndNameRow ¶ added in v0.0.6
type GetProfileByProjectAndNameRow struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Remediate NullActionType `json:"remediate"`
Alert NullActionType `json:"alert"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
ID_2 uuid.UUID `json:"id_2"`
Entity Entities `json:"entity"`
ProfileID uuid.UUID `json:"profile_id"`
ContextualRules json.RawMessage `json:"contextual_rules"`
CreatedAt_2 time.Time `json:"created_at_2"`
UpdatedAt_2 time.Time `json:"updated_at_2"`
}
type GetProfileStatusByIdAndProjectParams ¶ added in v0.0.6
type GetProfileStatusByIdAndProjectRow ¶ added in v0.0.6
type GetProfileStatusByNameAndProjectParams ¶ added in v0.0.6
type GetProfileStatusByNameAndProjectRow ¶ added in v0.0.6
type GetProfileStatusByProjectRow ¶ added in v0.0.6
type GetProjectIDPortBySessionStateRow ¶ added in v0.0.5
type GetProviderByIDParams ¶ added in v0.0.4
type GetProviderByNameParams ¶ added in v0.0.4
type GetRepositoryByIDAndProjectParams ¶ added in v0.0.5
type GetRoleByNameParams ¶
type GetRuleTypeByNameParams ¶
type GetUserProjectsRow ¶ added in v0.0.5
type GetUserProjectsRow struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
IsOrganization bool `json:"is_organization"`
Metadata json.RawMessage `json:"metadata"`
ParentID uuid.NullUUID `json:"parent_id"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
ID_2 int32 `json:"id_2"`
UserID int32 `json:"user_id"`
ProjectID uuid.UUID `json:"project_id"`
}
type GetUserRolesRow ¶
type GetUserRolesRow struct {
ID int32 `json:"id"`
OrganizationID uuid.UUID `json:"organization_id"`
ProjectID uuid.NullUUID `json:"project_id"`
Name string `json:"name"`
IsAdmin bool `json:"is_admin"`
IsProtected bool `json:"is_protected"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
ID_2 int32 `json:"id_2"`
UserID int32 `json:"user_id"`
RoleID int32 `json:"role_id"`
}
type ListOrganizationsParams ¶
type ListProfilesByProjectIDRow ¶ added in v0.0.6
type ListProfilesByProjectIDRow struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Remediate NullActionType `json:"remediate"`
Alert NullActionType `json:"alert"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
ID_2 uuid.UUID `json:"id_2"`
Entity Entities `json:"entity"`
ProfileID uuid.UUID `json:"profile_id"`
ContextualRules json.RawMessage `json:"contextual_rules"`
CreatedAt_2 time.Time `json:"created_at_2"`
UpdatedAt_2 time.Time `json:"updated_at_2"`
}
type ListProfilesInstantiatingRuleTypeRow ¶ added in v0.0.7
type ListRegisteredRepositoriesByProjectIDAndProviderParams ¶ added in v0.0.5
type ListRepositoriesByProjectIDParams ¶ added in v0.0.5
type ListRolesByProjectIDParams ¶ added in v0.0.5
type ListRolesParams ¶
type ListRuleEvaluationsByProfileIdParams ¶ added in v0.0.7
type ListRuleEvaluationsByProfileIdParams struct {
ProfileID uuid.UUID `json:"profile_id"`
EntityType NullEntities `json:"entity_type"`
EntityID uuid.NullUUID `json:"entity_id"`
RuleName sql.NullString `json:"rule_name"`
}
type ListRuleEvaluationsByProfileIdRow ¶ added in v0.0.7
type ListRuleEvaluationsByProfileIdRow struct {
EvalStatus NullEvalStatusTypes `json:"eval_status"`
EvalLastUpdated sql.NullTime `json:"eval_last_updated"`
EvalDetails sql.NullString `json:"eval_details"`
RemStatus NullRemediationStatusTypes `json:"rem_status"`
RemDetails sql.NullString `json:"rem_details"`
RemLastUpdated sql.NullTime `json:"rem_last_updated"`
AlertStatus NullAlertStatusTypes `json:"alert_status"`
AlertDetails sql.NullString `json:"alert_details"`
AlertLastUpdated sql.NullTime `json:"alert_last_updated"`
RepositoryID uuid.NullUUID `json:"repository_id"`
Entity Entities `json:"entity"`
RepoName string `json:"repo_name"`
RepoOwner string `json:"repo_owner"`
Provider string `json:"provider"`
RuleTypeName string `json:"rule_type_name"`
RuleTypeID uuid.UUID `json:"rule_type_id"`
}
type ListRuleTypesByProviderAndProjectParams ¶ added in v0.0.5
type ListUsersByProjectParams ¶ added in v0.0.5
type ListUsersParams ¶
type NullActionType ¶ added in v0.0.7
type NullActionType struct {
ActionType ActionType `json:"action_type"`
Valid bool `json:"valid"` // Valid is true if ActionType is not NULL
}
func (*NullActionType) Scan ¶ added in v0.0.7
func (ns *NullActionType) Scan(value interface{}) error
Scan implements the Scanner interface.
type NullAlertStatusTypes ¶ added in v0.0.7
type NullAlertStatusTypes struct {
AlertStatusTypes AlertStatusTypes `json:"alert_status_types"`
Valid bool `json:"valid"` // Valid is true if AlertStatusTypes is not NULL
}
func (*NullAlertStatusTypes) Scan ¶ added in v0.0.7
func (ns *NullAlertStatusTypes) Scan(value interface{}) error
Scan implements the Scanner interface.
type NullEntities ¶
type NullEntities struct {
Entities Entities `json:"entities"`
Valid bool `json:"valid"` // Valid is true if Entities is not NULL
}
func (*NullEntities) Scan ¶
func (ns *NullEntities) Scan(value interface{}) error
Scan implements the Scanner interface.
type NullEvalStatusTypes ¶
type NullEvalStatusTypes struct {
EvalStatusTypes EvalStatusTypes `json:"eval_status_types"`
Valid bool `json:"valid"` // Valid is true if EvalStatusTypes is not NULL
}
func (*NullEvalStatusTypes) Scan ¶
func (ns *NullEvalStatusTypes) Scan(value interface{}) error
Scan implements the Scanner interface.
type NullProviderType ¶ added in v0.0.4
type NullProviderType struct {
ProviderType ProviderType `json:"provider_type"`
Valid bool `json:"valid"` // Valid is true if ProviderType is not NULL
}
func (*NullProviderType) Scan ¶ added in v0.0.4
func (ns *NullProviderType) Scan(value interface{}) error
Scan implements the Scanner interface.
type NullRemediationStatusTypes ¶ added in v0.0.5
type NullRemediationStatusTypes struct {
RemediationStatusTypes RemediationStatusTypes `json:"remediation_status_types"`
Valid bool `json:"valid"` // Valid is true if RemediationStatusTypes is not NULL
}
func (*NullRemediationStatusTypes) Scan ¶ added in v0.0.5
func (ns *NullRemediationStatusTypes) Scan(value interface{}) error
Scan implements the Scanner interface.
type Profile ¶ added in v0.0.6
type Profile struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Remediate NullActionType `json:"remediate"`
Alert NullActionType `json:"alert"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type ProfileStatus ¶ added in v0.0.6
type Provider ¶ added in v0.0.4
type Provider struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Version string `json:"version"`
ProjectID uuid.UUID `json:"project_id"`
Implements []ProviderType `json:"implements"`
Definition json.RawMessage `json:"definition"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type ProviderAccessToken ¶
type ProviderAccessToken struct {
ID int32 `json:"id"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
OwnerFilter sql.NullString `json:"owner_filter"`
EncryptedToken string `json:"encrypted_token"`
ExpirationTime time.Time `json:"expiration_time"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type ProviderType ¶ added in v0.0.4
type ProviderType string
const ( ProviderTypeGithub ProviderType = "github" ProviderTypeRest ProviderType = "rest" ProviderTypeGit ProviderType = "git" ProviderTypeOci ProviderType = "oci" ProviderTypeRepoLister ProviderType = "repo-lister" )
func (*ProviderType) Scan ¶ added in v0.0.4
func (e *ProviderType) Scan(src interface{}) error
type Querier ¶
type Querier interface {
AddUserProject(ctx context.Context, arg AddUserProjectParams) (UserProject, error)
AddUserRole(ctx context.Context, arg AddUserRoleParams) (UserRole, error)
CreateAccessToken(ctx context.Context, arg CreateAccessTokenParams) (ProviderAccessToken, error)
CreateArtifact(ctx context.Context, arg CreateArtifactParams) (Artifact, error)
CreateArtifactVersion(ctx context.Context, arg CreateArtifactVersionParams) (ArtifactVersion, error)
CreateOrganization(ctx context.Context, arg CreateOrganizationParams) (Project, error)
CreateProfile(ctx context.Context, arg CreateProfileParams) (Profile, error)
CreateProfileForEntity(ctx context.Context, arg CreateProfileForEntityParams) (EntityProfile, error)
CreateProject(ctx context.Context, arg CreateProjectParams) (Project, error)
CreateProvider(ctx context.Context, arg CreateProviderParams) (Provider, error)
CreateRepository(ctx context.Context, arg CreateRepositoryParams) (Repository, error)
CreateRole(ctx context.Context, arg CreateRoleParams) (Role, error)
CreateRuleType(ctx context.Context, arg CreateRuleTypeParams) (RuleType, error)
CreateSessionState(ctx context.Context, arg CreateSessionStateParams) (SessionStore, error)
CreateSigningKey(ctx context.Context, arg CreateSigningKeyParams) (SigningKey, error)
CreateUser(ctx context.Context, arg CreateUserParams) (User, error)
DeleteAccessToken(ctx context.Context, arg DeleteAccessTokenParams) error
DeleteArtifact(ctx context.Context, id uuid.UUID) error
DeleteArtifactVersion(ctx context.Context, id uuid.UUID) error
DeleteExpiredSessionStates(ctx context.Context) error
DeleteOldArtifactVersions(ctx context.Context, arg DeleteOldArtifactVersionsParams) error
DeleteOrganization(ctx context.Context, id uuid.UUID) error
DeleteProfile(ctx context.Context, id uuid.UUID) error
DeleteProject(ctx context.Context, id uuid.UUID) ([]DeleteProjectRow, error)
DeleteProvider(ctx context.Context, arg DeleteProviderParams) error
DeleteRepository(ctx context.Context, id uuid.UUID) error
DeleteRole(ctx context.Context, id int32) error
DeleteRuleType(ctx context.Context, id uuid.UUID) error
DeleteSessionState(ctx context.Context, id int32) error
DeleteSessionStateByProjectID(ctx context.Context, arg DeleteSessionStateByProjectIDParams) error
DeleteSigningKey(ctx context.Context, arg DeleteSigningKeyParams) error
DeleteUser(ctx context.Context, id int32) error
GetAccessTokenByProjectID(ctx context.Context, arg GetAccessTokenByProjectIDParams) (ProviderAccessToken, error)
GetAccessTokenByProvider(ctx context.Context, provider string) ([]ProviderAccessToken, error)
GetAccessTokenSinceDate(ctx context.Context, arg GetAccessTokenSinceDateParams) (ProviderAccessToken, error)
GetArtifactByID(ctx context.Context, id uuid.UUID) (GetArtifactByIDRow, error)
GetArtifactVersionByID(ctx context.Context, id uuid.UUID) (ArtifactVersion, error)
GetArtifactVersionBySha(ctx context.Context, sha string) (ArtifactVersion, error)
GetChildrenProjects(ctx context.Context, id uuid.UUID) ([]GetChildrenProjectsRow, error)
GetOrganization(ctx context.Context, id uuid.UUID) (Project, error)
GetOrganizationByName(ctx context.Context, name string) (Project, error)
GetOrganizationForUpdate(ctx context.Context, name string) (Project, error)
GetParentProjects(ctx context.Context, id uuid.UUID) ([]uuid.UUID, error)
GetParentProjectsUntil(ctx context.Context, arg GetParentProjectsUntilParams) ([]uuid.UUID, error)
GetProfileByID(ctx context.Context, id uuid.UUID) (Profile, error)
GetProfileByProjectAndID(ctx context.Context, arg GetProfileByProjectAndIDParams) ([]GetProfileByProjectAndIDRow, error)
GetProfileByProjectAndName(ctx context.Context, arg GetProfileByProjectAndNameParams) ([]GetProfileByProjectAndNameRow, error)
GetProfileStatusByIdAndProject(ctx context.Context, arg GetProfileStatusByIdAndProjectParams) (GetProfileStatusByIdAndProjectRow, error)
GetProfileStatusByNameAndProject(ctx context.Context, arg GetProfileStatusByNameAndProjectParams) (GetProfileStatusByNameAndProjectRow, error)
GetProfileStatusByProject(ctx context.Context, projectID uuid.UUID) ([]GetProfileStatusByProjectRow, error)
GetProjectByID(ctx context.Context, id uuid.UUID) (Project, error)
GetProjectByName(ctx context.Context, name string) (Project, error)
GetProjectIDPortBySessionState(ctx context.Context, sessionState string) (GetProjectIDPortBySessionStateRow, error)
GetProviderByID(ctx context.Context, arg GetProviderByIDParams) (Provider, error)
GetProviderByName(ctx context.Context, arg GetProviderByNameParams) (Provider, error)
GetRepositoryByID(ctx context.Context, id uuid.UUID) (Repository, error)
GetRepositoryByIDAndProject(ctx context.Context, arg GetRepositoryByIDAndProjectParams) (Repository, error)
GetRepositoryByRepoID(ctx context.Context, repoID int32) (Repository, error)
GetRepositoryByRepoName(ctx context.Context, arg GetRepositoryByRepoNameParams) (Repository, error)
GetRoleByID(ctx context.Context, id int32) (Role, error)
GetRoleByName(ctx context.Context, arg GetRoleByNameParams) (Role, error)
GetRootProjects(ctx context.Context) ([]Project, error)
GetRuleTypeByID(ctx context.Context, id uuid.UUID) (RuleType, error)
GetRuleTypeByName(ctx context.Context, arg GetRuleTypeByNameParams) (RuleType, error)
GetSessionState(ctx context.Context, id int32) (SessionStore, error)
GetSessionStateByProjectID(ctx context.Context, projectID uuid.UUID) (SessionStore, error)
GetSigningKeyByIdentifier(ctx context.Context, keyIdentifier string) (SigningKey, error)
GetSigningKeyByProjectID(ctx context.Context, projectID uuid.UUID) (SigningKey, error)
GetUserByID(ctx context.Context, id int32) (User, error)
GetUserBySubject(ctx context.Context, identitySubject string) (User, error)
GetUserProjects(ctx context.Context, userID int32) ([]GetUserProjectsRow, error)
GetUserRoles(ctx context.Context, userID int32) ([]GetUserRolesRow, error)
GlobalListProviders(ctx context.Context) ([]Provider, error)
ListAllRepositories(ctx context.Context, provider string) ([]Repository, error)
ListArtifactVersionsByArtifactID(ctx context.Context, arg ListArtifactVersionsByArtifactIDParams) ([]ArtifactVersion, error)
ListArtifactVersionsByArtifactIDAndTag(ctx context.Context, arg ListArtifactVersionsByArtifactIDAndTagParams) ([]ArtifactVersion, error)
ListArtifactsByRepoID(ctx context.Context, repositoryID uuid.UUID) ([]Artifact, error)
ListOrganizations(ctx context.Context, arg ListOrganizationsParams) ([]Project, error)
ListProfilesByProjectID(ctx context.Context, projectID uuid.UUID) ([]ListProfilesByProjectIDRow, error)
// get profile information that instantiate a rule. This is done by joining the profiles with entity_profiles, then correlating those
// with entity_profile_rules. The rule_type_id is used to filter the results. Note that we only really care about the overal profile,
// so we only return the profile information. We also should group the profiles so that we don't get duplicates.
ListProfilesInstantiatingRuleType(ctx context.Context, ruleTypeID uuid.UUID) ([]ListProfilesInstantiatingRuleTypeRow, error)
ListProvidersByProjectID(ctx context.Context, projectID uuid.UUID) ([]Provider, error)
ListRegisteredRepositoriesByProjectIDAndProvider(ctx context.Context, arg ListRegisteredRepositoriesByProjectIDAndProviderParams) ([]Repository, error)
ListRepositoriesByOwner(ctx context.Context, arg ListRepositoriesByOwnerParams) ([]Repository, error)
ListRepositoriesByProjectID(ctx context.Context, arg ListRepositoriesByProjectIDParams) ([]Repository, error)
ListRoles(ctx context.Context, arg ListRolesParams) ([]Role, error)
ListRolesByProjectID(ctx context.Context, arg ListRolesByProjectIDParams) ([]Role, error)
ListRuleEvaluationsByProfileId(ctx context.Context, arg ListRuleEvaluationsByProfileIdParams) ([]ListRuleEvaluationsByProfileIdRow, error)
ListRuleTypesByProviderAndProject(ctx context.Context, arg ListRuleTypesByProviderAndProjectParams) ([]RuleType, error)
ListUsers(ctx context.Context, arg ListUsersParams) ([]User, error)
ListUsersByOrganization(ctx context.Context, arg ListUsersByOrganizationParams) ([]User, error)
ListUsersByProject(ctx context.Context, arg ListUsersByProjectParams) ([]User, error)
ListUsersByRoleId(ctx context.Context, roleID int32) ([]int32, error)
UpdateAccessToken(ctx context.Context, arg UpdateAccessTokenParams) (ProviderAccessToken, error)
UpdateOrganization(ctx context.Context, arg UpdateOrganizationParams) (Project, error)
// set clone_url if the value is not an empty string
UpdateRepository(ctx context.Context, arg UpdateRepositoryParams) (Repository, error)
UpdateRepositoryByID(ctx context.Context, arg UpdateRepositoryByIDParams) (Repository, error)
UpdateRole(ctx context.Context, arg UpdateRoleParams) (Role, error)
UpdateRuleType(ctx context.Context, arg UpdateRuleTypeParams) error
UpsertArtifact(ctx context.Context, arg UpsertArtifactParams) (Artifact, error)
UpsertArtifactVersion(ctx context.Context, arg UpsertArtifactVersionParams) (ArtifactVersion, error)
UpsertRuleDetailsAlert(ctx context.Context, arg UpsertRuleDetailsAlertParams) (uuid.UUID, error)
UpsertRuleDetailsEval(ctx context.Context, arg UpsertRuleDetailsEvalParams) (uuid.UUID, error)
UpsertRuleDetailsRemediate(ctx context.Context, arg UpsertRuleDetailsRemediateParams) (uuid.UUID, error)
UpsertRuleEvaluations(ctx context.Context, arg UpsertRuleEvaluationsParams) (uuid.UUID, error)
UpsertRuleInstantiation(ctx context.Context, arg UpsertRuleInstantiationParams) (EntityProfileRule, error)
}
type Queries ¶
type Queries struct {
// contains filtered or unexported fields
}
func (*Queries) AddUserProject ¶ added in v0.0.5
func (q *Queries) AddUserProject(ctx context.Context, arg AddUserProjectParams) (UserProject, error)
func (*Queries) AddUserRole ¶
func (*Queries) CreateAccessToken ¶
func (q *Queries) CreateAccessToken(ctx context.Context, arg CreateAccessTokenParams) (ProviderAccessToken, error)
func (*Queries) CreateArtifact ¶
func (*Queries) CreateArtifactVersion ¶
func (q *Queries) CreateArtifactVersion(ctx context.Context, arg CreateArtifactVersionParams) (ArtifactVersion, error)
func (*Queries) CreateOrganization ¶
func (*Queries) CreateProfile ¶ added in v0.0.6
func (*Queries) CreateProfileForEntity ¶ added in v0.0.6
func (q *Queries) CreateProfileForEntity(ctx context.Context, arg CreateProfileForEntityParams) (EntityProfile, error)
func (*Queries) CreateProject ¶
func (*Queries) CreateProvider ¶ added in v0.0.4
func (*Queries) CreateRepository ¶
func (q *Queries) CreateRepository(ctx context.Context, arg CreateRepositoryParams) (Repository, error)
func (*Queries) CreateRole ¶
func (*Queries) CreateRuleType ¶
func (*Queries) CreateSessionState ¶
func (q *Queries) CreateSessionState(ctx context.Context, arg CreateSessionStateParams) (SessionStore, error)
func (*Queries) CreateSigningKey ¶
func (q *Queries) CreateSigningKey(ctx context.Context, arg CreateSigningKeyParams) (SigningKey, error)
func (*Queries) CreateUser ¶
func (*Queries) DeleteAccessToken ¶
func (q *Queries) DeleteAccessToken(ctx context.Context, arg DeleteAccessTokenParams) error
func (*Queries) DeleteArtifact ¶
func (*Queries) DeleteArtifactVersion ¶
func (*Queries) DeleteExpiredSessionStates ¶
func (*Queries) DeleteOldArtifactVersions ¶
func (q *Queries) DeleteOldArtifactVersions(ctx context.Context, arg DeleteOldArtifactVersionsParams) error
func (*Queries) DeleteOrganization ¶
func (*Queries) DeleteProfile ¶ added in v0.0.6
func (*Queries) DeleteProject ¶
func (*Queries) DeleteProvider ¶ added in v0.0.4
func (q *Queries) DeleteProvider(ctx context.Context, arg DeleteProviderParams) error
func (*Queries) DeleteRepository ¶
func (*Queries) DeleteRuleType ¶
func (*Queries) DeleteSessionState ¶
func (*Queries) DeleteSessionStateByProjectID ¶ added in v0.0.5
func (q *Queries) DeleteSessionStateByProjectID(ctx context.Context, arg DeleteSessionStateByProjectIDParams) error
func (*Queries) DeleteSigningKey ¶
func (q *Queries) DeleteSigningKey(ctx context.Context, arg DeleteSigningKeyParams) error
func (*Queries) GetAccessTokenByProjectID ¶ added in v0.0.5
func (q *Queries) GetAccessTokenByProjectID(ctx context.Context, arg GetAccessTokenByProjectIDParams) (ProviderAccessToken, error)
func (*Queries) GetAccessTokenByProvider ¶
func (*Queries) GetAccessTokenSinceDate ¶
func (q *Queries) GetAccessTokenSinceDate(ctx context.Context, arg GetAccessTokenSinceDateParams) (ProviderAccessToken, error)
func (*Queries) GetArtifactByID ¶
func (*Queries) GetArtifactVersionByID ¶
func (*Queries) GetArtifactVersionBySha ¶
func (*Queries) GetChildrenProjects ¶
func (*Queries) GetOrganization ¶
func (*Queries) GetOrganizationByName ¶
func (*Queries) GetOrganizationForUpdate ¶
func (*Queries) GetParentProjects ¶
func (*Queries) GetParentProjectsUntil ¶
func (*Queries) GetProfileByID ¶ added in v0.0.6
func (*Queries) GetProfileByProjectAndID ¶ added in v0.0.6
func (q *Queries) GetProfileByProjectAndID(ctx context.Context, arg GetProfileByProjectAndIDParams) ([]GetProfileByProjectAndIDRow, error)
func (*Queries) GetProfileByProjectAndName ¶ added in v0.0.6
func (q *Queries) GetProfileByProjectAndName(ctx context.Context, arg GetProfileByProjectAndNameParams) ([]GetProfileByProjectAndNameRow, error)
func (*Queries) GetProfileStatusByIdAndProject ¶ added in v0.0.6
func (q *Queries) GetProfileStatusByIdAndProject(ctx context.Context, arg GetProfileStatusByIdAndProjectParams) (GetProfileStatusByIdAndProjectRow, error)
func (*Queries) GetProfileStatusByNameAndProject ¶ added in v0.0.6
func (q *Queries) GetProfileStatusByNameAndProject(ctx context.Context, arg GetProfileStatusByNameAndProjectParams) (GetProfileStatusByNameAndProjectRow, error)
func (*Queries) GetProfileStatusByProject ¶ added in v0.0.6
func (*Queries) GetProjectByID ¶
func (*Queries) GetProjectByName ¶ added in v0.0.5
func (*Queries) GetProjectIDPortBySessionState ¶ added in v0.0.5
func (*Queries) GetProviderByID ¶ added in v0.0.4
func (*Queries) GetProviderByName ¶ added in v0.0.4
func (*Queries) GetRepositoryByID ¶
func (*Queries) GetRepositoryByIDAndProject ¶ added in v0.0.5
func (q *Queries) GetRepositoryByIDAndProject(ctx context.Context, arg GetRepositoryByIDAndProjectParams) (Repository, error)
func (*Queries) GetRepositoryByRepoID ¶
func (*Queries) GetRepositoryByRepoName ¶
func (q *Queries) GetRepositoryByRepoName(ctx context.Context, arg GetRepositoryByRepoNameParams) (Repository, error)
func (*Queries) GetRoleByID ¶
func (*Queries) GetRoleByName ¶
func (*Queries) GetRootProjects ¶
func (*Queries) GetRuleTypeByID ¶
func (*Queries) GetRuleTypeByName ¶
func (*Queries) GetSessionState ¶
func (*Queries) GetSessionStateByProjectID ¶ added in v0.0.5
func (*Queries) GetSigningKeyByIdentifier ¶
func (*Queries) GetSigningKeyByProjectID ¶ added in v0.0.5
func (*Queries) GetUserByID ¶
func (*Queries) GetUserBySubject ¶ added in v0.0.4
func (*Queries) GetUserProjects ¶ added in v0.0.5
func (*Queries) GetUserRoles ¶
func (*Queries) GlobalListProviders ¶ added in v0.0.4
func (*Queries) ListAllRepositories ¶
func (*Queries) ListArtifactVersionsByArtifactID ¶
func (q *Queries) ListArtifactVersionsByArtifactID(ctx context.Context, arg ListArtifactVersionsByArtifactIDParams) ([]ArtifactVersion, error)
func (*Queries) ListArtifactVersionsByArtifactIDAndTag ¶
func (q *Queries) ListArtifactVersionsByArtifactIDAndTag(ctx context.Context, arg ListArtifactVersionsByArtifactIDAndTagParams) ([]ArtifactVersion, error)
func (*Queries) ListArtifactsByRepoID ¶
func (*Queries) ListOrganizations ¶
func (*Queries) ListProfilesByProjectID ¶ added in v0.0.6
func (*Queries) ListProfilesInstantiatingRuleType ¶ added in v0.0.7
func (q *Queries) ListProfilesInstantiatingRuleType(ctx context.Context, ruleTypeID uuid.UUID) ([]ListProfilesInstantiatingRuleTypeRow, error)
get profile information that instantiate a rule. This is done by joining the profiles with entity_profiles, then correlating those with entity_profile_rules. The rule_type_id is used to filter the results. Note that we only really care about the overal profile, so we only return the profile information. We also should group the profiles so that we don't get duplicates.
func (*Queries) ListProvidersByProjectID ¶ added in v0.0.5
func (*Queries) ListRegisteredRepositoriesByProjectIDAndProvider ¶ added in v0.0.5
func (q *Queries) ListRegisteredRepositoriesByProjectIDAndProvider(ctx context.Context, arg ListRegisteredRepositoriesByProjectIDAndProviderParams) ([]Repository, error)
func (*Queries) ListRepositoriesByOwner ¶
func (q *Queries) ListRepositoriesByOwner(ctx context.Context, arg ListRepositoriesByOwnerParams) ([]Repository, error)
func (*Queries) ListRepositoriesByProjectID ¶ added in v0.0.5
func (q *Queries) ListRepositoriesByProjectID(ctx context.Context, arg ListRepositoriesByProjectIDParams) ([]Repository, error)
func (*Queries) ListRolesByProjectID ¶ added in v0.0.5
func (*Queries) ListRuleEvaluationsByProfileId ¶ added in v0.0.7
func (q *Queries) ListRuleEvaluationsByProfileId(ctx context.Context, arg ListRuleEvaluationsByProfileIdParams) ([]ListRuleEvaluationsByProfileIdRow, error)
func (*Queries) ListRuleTypesByProviderAndProject ¶ added in v0.0.5
func (*Queries) ListUsersByOrganization ¶
func (*Queries) ListUsersByProject ¶ added in v0.0.5
func (*Queries) ListUsersByRoleId ¶
func (*Queries) UpdateAccessToken ¶
func (q *Queries) UpdateAccessToken(ctx context.Context, arg UpdateAccessTokenParams) (ProviderAccessToken, error)
func (*Queries) UpdateOrganization ¶
func (*Queries) UpdateRepository ¶
func (q *Queries) UpdateRepository(ctx context.Context, arg UpdateRepositoryParams) (Repository, error)
set clone_url if the value is not an empty string
func (*Queries) UpdateRepositoryByID ¶
func (q *Queries) UpdateRepositoryByID(ctx context.Context, arg UpdateRepositoryByIDParams) (Repository, error)
func (*Queries) UpdateRole ¶
func (*Queries) UpdateRuleType ¶
func (q *Queries) UpdateRuleType(ctx context.Context, arg UpdateRuleTypeParams) error
func (*Queries) UpsertArtifact ¶
func (*Queries) UpsertArtifactVersion ¶
func (q *Queries) UpsertArtifactVersion(ctx context.Context, arg UpsertArtifactVersionParams) (ArtifactVersion, error)
func (*Queries) UpsertRuleDetailsAlert ¶ added in v0.0.7
func (*Queries) UpsertRuleDetailsEval ¶ added in v0.0.7
func (*Queries) UpsertRuleDetailsRemediate ¶ added in v0.0.7
func (*Queries) UpsertRuleEvaluations ¶ added in v0.0.7
func (*Queries) UpsertRuleInstantiation ¶ added in v0.0.7
func (q *Queries) UpsertRuleInstantiation(ctx context.Context, arg UpsertRuleInstantiationParams) (EntityProfileRule, error)
type RemediationStatusTypes ¶ added in v0.0.5
type RemediationStatusTypes string
const ( RemediationStatusTypesSuccess RemediationStatusTypes = "success" RemediationStatusTypesFailure RemediationStatusTypes = "failure" RemediationStatusTypesError RemediationStatusTypes = "error" RemediationStatusTypesSkipped RemediationStatusTypes = "skipped" RemediationStatusTypesNotAvailable RemediationStatusTypes = "not_available" )
func (*RemediationStatusTypes) Scan ¶ added in v0.0.5
func (e *RemediationStatusTypes) Scan(src interface{}) error
type Repository ¶
type Repository struct {
ID uuid.UUID `json:"id"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
RepoOwner string `json:"repo_owner"`
RepoName string `json:"repo_name"`
RepoID int32 `json:"repo_id"`
IsPrivate bool `json:"is_private"`
IsFork bool `json:"is_fork"`
WebhookID sql.NullInt32 `json:"webhook_id"`
WebhookUrl string `json:"webhook_url"`
DeployUrl string `json:"deploy_url"`
CloneUrl string `json:"clone_url"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type Role ¶
type Role struct {
ID int32 `json:"id"`
OrganizationID uuid.UUID `json:"organization_id"`
ProjectID uuid.NullUUID `json:"project_id"`
Name string `json:"name"`
IsAdmin bool `json:"is_admin"`
IsProtected bool `json:"is_protected"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type RuleDetailsAlert ¶ added in v0.0.7
type RuleDetailsAlert struct {
ID uuid.UUID `json:"id"`
RuleEvalID uuid.UUID `json:"rule_eval_id"`
Status AlertStatusTypes `json:"status"`
Details string `json:"details"`
Metadata json.RawMessage `json:"metadata"`
LastUpdated time.Time `json:"last_updated"`
}
type RuleDetailsEval ¶ added in v0.0.7
type RuleDetailsRemediate ¶ added in v0.0.7
type RuleEvaluation ¶ added in v0.0.7
type RuleType ¶
type RuleType struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Provider string `json:"provider"`
ProjectID uuid.UUID `json:"project_id"`
Description string `json:"description"`
Guidance string `json:"guidance"`
Definition json.RawMessage `json:"definition"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type SQLStore ¶
type SQLStore struct {
*Queries
// contains filtered or unexported fields
}
SQLStore provides all functions to execute SQL queries and transactions
func (*SQLStore) BeginTransaction ¶
BeginTransaction begins a new transaction
func (*SQLStore) CheckHealth ¶
CheckHealth checks the health of the database
func (*SQLStore) GetQuerierWithTransaction ¶
GetQuerierWithTransaction returns a new Querier with the provided transaction
type SessionStore ¶
type SigningKey ¶
type SigningKey struct {
ID int32 `json:"id"`
ProjectID uuid.UUID `json:"project_id"`
PrivateKey string `json:"private_key"`
PublicKey string `json:"public_key"`
Passphrase string `json:"passphrase"`
KeyIdentifier string `json:"key_identifier"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type Store ¶
type Store interface {
Querier
CheckHealth() error
BeginTransaction() (*sql.Tx, error)
GetQuerierWithTransaction(tx *sql.Tx) Querier
Commit(tx *sql.Tx) error
Rollback(tx *sql.Tx) error
}
Store provides all functions to execute db queries and transactions
type UpdateAccessTokenParams ¶
type UpdateOrganizationParams ¶
type UpdateOrganizationParams struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
Metadata json.RawMessage `json:"metadata"`
}
type UpdateRepositoryByIDParams ¶
type UpdateRepositoryByIDParams struct {
RepoID int32 `json:"repo_id"`
ProjectID uuid.UUID `json:"project_id"`
RepoOwner string `json:"repo_owner"`
RepoName string `json:"repo_name"`
IsPrivate bool `json:"is_private"`
IsFork bool `json:"is_fork"`
WebhookID sql.NullInt32 `json:"webhook_id"`
WebhookUrl string `json:"webhook_url"`
DeployUrl string `json:"deploy_url"`
Provider string `json:"provider"`
CloneUrl string `json:"clone_url"`
}
type UpdateRepositoryParams ¶
type UpdateRepositoryParams struct {
ID uuid.UUID `json:"id"`
ProjectID uuid.UUID `json:"project_id"`
RepoOwner string `json:"repo_owner"`
RepoName string `json:"repo_name"`
RepoID int32 `json:"repo_id"`
IsPrivate bool `json:"is_private"`
IsFork bool `json:"is_fork"`
WebhookID sql.NullInt32 `json:"webhook_id"`
WebhookUrl string `json:"webhook_url"`
DeployUrl string `json:"deploy_url"`
Provider string `json:"provider"`
CloneUrl string `json:"clone_url"`
}
type UpdateRoleParams ¶
type UpdateRuleTypeParams ¶
type UpdateRuleTypeParams struct {
ID uuid.UUID `json:"id"`
Description string `json:"description"`
Definition json.RawMessage `json:"definition"`
}
type UpsertArtifactParams ¶
type UpsertArtifactVersionParams ¶
type UpsertArtifactVersionParams struct {
ArtifactID uuid.UUID `json:"artifact_id"`
Version int64 `json:"version"`
Tags sql.NullString `json:"tags"`
Sha string `json:"sha"`
CreatedAt time.Time `json:"created_at"`
SignatureVerification json.RawMessage `json:"signature_verification"`
GithubWorkflow json.RawMessage `json:"github_workflow"`
}
type UpsertRuleDetailsAlertParams ¶ added in v0.0.7
type UpsertRuleDetailsAlertParams struct {
RuleEvalID uuid.UUID `json:"rule_eval_id"`
Status AlertStatusTypes `json:"status"`
Details string `json:"details"`
}
type UpsertRuleDetailsEvalParams ¶ added in v0.0.7
type UpsertRuleDetailsEvalParams struct {
RuleEvalID uuid.UUID `json:"rule_eval_id"`
Status EvalStatusTypes `json:"status"`
Details string `json:"details"`
}
type UpsertRuleDetailsRemediateParams ¶ added in v0.0.7
type UpsertRuleDetailsRemediateParams struct {
RuleEvalID uuid.UUID `json:"rule_eval_id"`
Status RemediationStatusTypes `json:"status"`
Details string `json:"details"`
}
type UpsertRuleEvaluationsParams ¶ added in v0.0.7
type UpsertRuleInstantiationParams ¶ added in v0.0.7
type User ¶
type User struct {
ID int32 `json:"id"`
OrganizationID uuid.UUID `json:"organization_id"`
Email sql.NullString `json:"email"`
IdentitySubject string `json:"identity_subject"`
FirstName sql.NullString `json:"first_name"`
LastName sql.NullString `json:"last_name"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
type UserProject ¶ added in v0.0.5
Source Files
¶
- artifact_versions.sql.go
- artifacts.sql.go
- db.go
- models.go
- organizations.sql.go
- profile_status.sql.go
- profiles.sql.go
- projects.sql.go
- projects_helpers.go
- provider_access_tokens.sql.go
- providers.sql.go
- querier.go
- repositories.sql.go
- roles.sql.go
- rule_types.sql.go
- session_store.sql.go
- signing_keys.sql.go
- store.go
- user_projects.sql.go
- user_roles.sql.go
- users.sql.go