errors

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2023 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package errors provides errors for the evaluator engine

Index

Constants

This section is empty.

Variables

var ErrEvaluationFailed = errors.New("evaluation failure")

ErrEvaluationFailed is an error that occurs during evaluation of a rule.

var ErrEvaluationSkipSilently = errors.New("evaluation skipped silently")

ErrEvaluationSkipSilently specifies that the rule was evaluated but skipped silently.

var ErrEvaluationSkipped = errors.New("evaluation skipped")

ErrEvaluationSkipped specifies that the rule was evaluated but skipped.

var ErrRemediateFailed = errors.New("remediation failed")

ErrRemediateFailed is an error code that indicates that the remediation was attempted but failed.

var ErrRemediationNotAvailable = errors.New("remediation not available")

ErrRemediationNotAvailable is an error code that indicates that the remediation was not available for this rule_type

var ErrRemediationSkipped = errors.New("remediation not performed")

ErrRemediationSkipped is an error code that indicates that the remediation was not performed at all because the evaluation passed and the remediation was not needed.

Functions

func IsRemediateFatalError added in v0.0.5

func IsRemediateFatalError(err error) bool

IsRemediateFatalError returns true if the error is a fatal error that should stop be reported to the user

func IsRemediateInformativeError added in v0.0.5

func IsRemediateInformativeError(err error) bool

IsRemediateInformativeError returns true if the error is an informative error that should not be reported to the user

func NewErrEvaluationFailed

func NewErrEvaluationFailed(sfmt string, args ...any) error

NewErrEvaluationFailed creates a new evaluation error

func NewErrEvaluationSkipSilently

func NewErrEvaluationSkipSilently(sfmt string, args ...any) error

NewErrEvaluationSkipSilently creates a new evaluation error

func NewErrEvaluationSkipped

func NewErrEvaluationSkipped(sfmt string, args ...any) error

NewErrEvaluationSkipped creates a new evaluation error

func NewErrRemediationFailed added in v0.0.5

func NewErrRemediationFailed(sfmt string, args ...any) error

NewErrRemediationFailed creates a new remediation error

Types

This section is empty.

Jump to