Documentation
¶
Overview ¶
Package artifact provides the artifact ingestion engine
Package artifact provides the artifact ingestion engine
Index ¶
Constants ¶
const (
// ArtifactRuleDataIngestType is the type of the artifact rule data ingest engine
ArtifactRuleDataIngestType = "artifact"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ingest ¶
type Ingest struct {
}
Ingest is the engine for a rule type that uses artifact data ingest Implements enginer.ingester.Ingester
func NewArtifactDataIngest ¶
func NewArtifactDataIngest( _ *pb.ArtifactType, ) (*Ingest, error)
NewArtifactDataIngest creates a new artifact rule data ingest engine
Click to show internal directories.
Click to hide internal directories.