Documentation
¶
Overview ¶
Package diff provides the diff rule data ingest engine
Package diff provides the diff rule data ingest engine ¶
Package diff provides the diff rule data ingest engine
Index ¶
Constants ¶
const (
// DiffRuleDataIngestType is the type of the diff rule data ingest engine
DiffRuleDataIngestType = "diff"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DependencyEcosystem ¶
type DependencyEcosystem string
DependencyEcosystem is the type of dependency ecosystem
const ( // DepEcosystemNPM is the npm dependency ecosystem DepEcosystemNPM DependencyEcosystem = "npm" // DepEcosystemNone is the fallback value DepEcosystemNone DependencyEcosystem = "" )
type Diff ¶
type Diff struct {
// contains filtered or unexported fields
}
Diff is the diff rule data ingest engine
func NewDiffIngester ¶
NewDiffIngester creates a new diff ingester
type EcosystemMapping ¶
type EcosystemMapping struct {
Ecosystem DependencyEcosystem `json:"ecosystem" yaml:"ecosystem" mapstructure:"ecosystem"`
Files []string `json:"files" yaml:"files" mapstructure:"files"`
}
EcosystemMapping is the mapping of a dependency ecosystem to a set of files
type IngesterConfig ¶
type IngesterConfig struct {
Ecosystems []EcosystemMapping `json:"ecosystems" yaml:"ecosystems" mapstructure:"ecosystems"`
}
IngesterConfig is the policy-provided configuration for the git ingester This allows for users to pass in configuration to the ingester in different calls as opposed to having to set it in the rule type.
Click to show internal directories.
Click to hide internal directories.