Documentation
¶
Overview ¶
Package entities contains internal helper functions to deal with, validate and print the Entity protobuf enum. Mostly to interact with the database.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EntityTypeFromDB ¶
EntityTypeFromDB returns the entity type from the database entity
func EntityTypeToDB ¶
EntityTypeToDB returns the database entity from the protobuf entity type
func KnownTypesCSV ¶
func KnownTypesCSV() string
KnownTypesCSV returns a comma separated list of known entity types. Useful for UI
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.