Documentation
¶
Overview ¶
Package mockgh is a generated GoMock package.
Index ¶
- type MockGit
- type MockGitHub
- func (m *MockGitHub) CloseSecurityAdvisory(ctx context.Context, owner, repo, id string) error
- func (m *MockGitHub) CreateBlob(ctx context.Context, owner, repo string, blob *github.Blob) (*github.Blob, error)
- func (m *MockGitHub) CreateComment(ctx context.Context, owner, repo string, number int, comment string) error
- func (m *MockGitHub) CreateCommit(ctx context.Context, owner, repo, message string, tree *github.Tree, ...) (*github.Commit, error)
- func (m *MockGitHub) CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)
- func (m *MockGitHub) CreatePullRequest(ctx context.Context, owner, repo, title, body, head, base string) (*github.PullRequest, error)
- func (m *MockGitHub) CreateRef(ctx context.Context, owner, repo, ref, sha string) (*github.Reference, error)
- func (m *MockGitHub) CreateReview(arg0 context.Context, arg1, arg2 string, arg3 int, ...) (*github.PullRequestReview, error)
- func (m *MockGitHub) CreateSecurityAdvisory(ctx context.Context, owner, repo, severity, summary, description string, ...) (string, error)
- func (m *MockGitHub) CreateTree(ctx context.Context, owner, repo, base string, entries []*github.TreeEntry) (*github.Tree, error)
- func (m *MockGitHub) DeleteHook(ctx context.Context, owner, repo string, id int64) error
- func (m *MockGitHub) DismissReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, ...) (*github.PullRequestReview, error)
- func (m *MockGitHub) Do(ctx context.Context, req *http.Request) (*http.Response, error)
- func (m *MockGitHub) EXPECT() *MockGitHubMockRecorder
- func (m *MockGitHub) GetAuthenticatedUser(arg0 context.Context) (*github.User, error)
- func (m *MockGitHub) GetBaseURL() string
- func (m *MockGitHub) GetBranchProtection(arg0 context.Context, arg1, arg2, arg3 string) (*github.Protection, error)
- func (m *MockGitHub) GetCommit(ctx context.Context, owner, repo, commitSHA string) (*github.Commit, error)
- func (m *MockGitHub) GetOwner() string
- func (m *MockGitHub) GetPackageByName(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) (*github.Package, error)
- func (m *MockGitHub) GetPackageVersionById(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string, arg5 int64) (*github.PackageVersion, error)
- func (m *MockGitHub) GetPackageVersionByTag(arg0 context.Context, arg1 bool, arg2, arg3, arg4, arg5 string) (*github.PackageVersion, error)
- func (m *MockGitHub) GetPackageVersions(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) ([]*github.PackageVersion, error)
- func (m *MockGitHub) GetPullRequest(arg0 context.Context, arg1, arg2 string, arg3 int) (*github.PullRequest, error)
- func (m *MockGitHub) GetRef(ctx context.Context, owner, repo, refString string) (*github.Reference, error)
- func (m *MockGitHub) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)
- func (m *MockGitHub) GetToken() string
- func (m *MockGitHub) ListAllPackages(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4, arg5 int) ([]*github.Package, error)
- func (m *MockGitHub) ListAllRepositories(arg0 context.Context, arg1 bool, arg2 string) ([]*github.Repository, error)
- func (m *MockGitHub) ListFiles(ctx context.Context, owner, repo string, prNumber, perPage, pageNumber int) ([]*github.CommitFile, *github.Response, error)
- func (m *MockGitHub) ListHooks(ctx context.Context, owner, repo string) ([]*github.Hook, error)
- func (m *MockGitHub) ListOrganizationRepsitories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
- func (m *MockGitHub) ListPackagesByRepository(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4 int64, arg5, arg6 int) ([]*github.Package, error)
- func (m *MockGitHub) ListPullRequests(ctx context.Context, owner, repo string, opt *github.PullRequestListOptions) ([]*github.PullRequest, error)
- func (m *MockGitHub) ListReviews(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.ListOptions) ([]*github.PullRequestReview, error)
- func (m *MockGitHub) ListUserRepositories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
- func (m *MockGitHub) NewRequest(method, url string, body any) (*http.Request, error)
- func (m *MockGitHub) SetCommitStatus(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.RepoStatus) (*github.RepoStatus, error)
- func (m *MockGitHub) UpdateBranchProtection(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.ProtectionRequest) error
- func (m *MockGitHub) UpdateRef(ctx context.Context, owner, repo, ref, sha string, force bool) (*github.Reference, error)
- type MockGitHubMockRecorder
- func (mr *MockGitHubMockRecorder) CloseSecurityAdvisory(ctx, owner, repo, id interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateBlob(ctx, owner, repo, blob interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateComment(ctx, owner, repo, number, comment interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateCommit(ctx, owner, repo, message, tree, parentSha interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateHook(ctx, owner, repo, hook interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreatePullRequest(ctx, owner, repo, title, body, head, base interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateRef(ctx, owner, repo, ref, sha interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateReview(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateSecurityAdvisory(ctx, owner, repo, severity, summary, description, v interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) CreateTree(ctx, owner, repo, base, entries interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) DeleteHook(ctx, owner, repo, id interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) DismissReview(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) Do(ctx, req interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetAuthenticatedUser(arg0 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetBaseURL() *gomock.Call
- func (mr *MockGitHubMockRecorder) GetBranchProtection(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetCommit(ctx, owner, repo, commitSHA interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetOwner() *gomock.Call
- func (mr *MockGitHubMockRecorder) GetPackageByName(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetPackageVersionById(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetPackageVersionByTag(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetPackageVersions(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetPullRequest(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetRef(ctx, owner, repo, refString interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetRepository(arg0, arg1, arg2 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) GetToken() *gomock.Call
- func (mr *MockGitHubMockRecorder) ListAllPackages(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListAllRepositories(arg0, arg1, arg2 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListFiles(ctx, owner, repo, prNumber, perPage, pageNumber interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListHooks(ctx, owner, repo interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListOrganizationRepsitories(arg0, arg1 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListPackagesByRepository(arg0, arg1, arg2, arg3, arg4, arg5, arg6 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListPullRequests(ctx, owner, repo, opt interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListReviews(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) ListUserRepositories(arg0, arg1 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) NewRequest(method, url, body interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) SetCommitStatus(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) UpdateBranchProtection(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockGitHubMockRecorder) UpdateRef(ctx, owner, repo, ref, sha, force interface{}) *gomock.Call
- type MockGitMockRecorder
- type MockProvider
- type MockProviderMockRecorder
- type MockREST
- type MockRESTMockRecorder
- type MockRepoLister
- func (m *MockRepoLister) EXPECT() *MockRepoListerMockRecorder
- func (m *MockRepoLister) GetToken() string
- func (m *MockRepoLister) ListOrganizationRepsitories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
- func (m *MockRepoLister) ListUserRepositories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
- type MockRepoListerMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockGit ¶ added in v0.0.4
type MockGit struct {
// contains filtered or unexported fields
}
MockGit is a mock of Git interface.
func NewMockGit ¶ added in v0.0.4
func NewMockGit(ctrl *gomock.Controller) *MockGit
NewMockGit creates a new mock instance.
func (*MockGit) EXPECT ¶ added in v0.0.4
func (m *MockGit) EXPECT() *MockGitMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockGitHub ¶ added in v0.0.4
type MockGitHub struct {
// contains filtered or unexported fields
}
MockGitHub is a mock of GitHub interface.
func NewMockGitHub ¶ added in v0.0.4
func NewMockGitHub(ctrl *gomock.Controller) *MockGitHub
NewMockGitHub creates a new mock instance.
func (*MockGitHub) CloseSecurityAdvisory ¶ added in v0.0.7
func (m *MockGitHub) CloseSecurityAdvisory(ctx context.Context, owner, repo, id string) error
CloseSecurityAdvisory mocks base method.
func (*MockGitHub) CreateBlob ¶ added in v0.0.9
func (m *MockGitHub) CreateBlob(ctx context.Context, owner, repo string, blob *github.Blob) (*github.Blob, error)
CreateBlob mocks base method.
func (*MockGitHub) CreateComment ¶ added in v0.0.9
func (m *MockGitHub) CreateComment(ctx context.Context, owner, repo string, number int, comment string) error
CreateComment mocks base method.
func (*MockGitHub) CreateCommit ¶ added in v0.0.9
func (m *MockGitHub) CreateCommit(ctx context.Context, owner, repo, message string, tree *github.Tree, parentSha string) (*github.Commit, error)
CreateCommit mocks base method.
func (*MockGitHub) CreateHook ¶ added in v0.0.7
func (m *MockGitHub) CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)
CreateHook mocks base method.
func (*MockGitHub) CreatePullRequest ¶ added in v0.0.9
func (m *MockGitHub) CreatePullRequest(ctx context.Context, owner, repo, title, body, head, base string) (*github.PullRequest, error)
CreatePullRequest mocks base method.
func (*MockGitHub) CreateRef ¶ added in v0.0.9
func (m *MockGitHub) CreateRef(ctx context.Context, owner, repo, ref, sha string) (*github.Reference, error)
CreateRef mocks base method.
func (*MockGitHub) CreateReview ¶ added in v0.0.4
func (m *MockGitHub) CreateReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.PullRequestReviewRequest) (*github.PullRequestReview, error)
CreateReview mocks base method.
func (*MockGitHub) CreateSecurityAdvisory ¶ added in v0.0.7
func (m *MockGitHub) CreateSecurityAdvisory(ctx context.Context, owner, repo, severity, summary, description string, v []*github.AdvisoryVulnerability) (string, error)
CreateSecurityAdvisory mocks base method.
func (*MockGitHub) CreateTree ¶ added in v0.0.9
func (m *MockGitHub) CreateTree(ctx context.Context, owner, repo, base string, entries []*github.TreeEntry) (*github.Tree, error)
CreateTree mocks base method.
func (*MockGitHub) DeleteHook ¶ added in v0.0.7
DeleteHook mocks base method.
func (*MockGitHub) DismissReview ¶ added in v0.0.4
func (m *MockGitHub) DismissReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, arg5 *github.PullRequestReviewDismissalRequest) (*github.PullRequestReview, error)
DismissReview mocks base method.
func (*MockGitHub) EXPECT ¶ added in v0.0.4
func (m *MockGitHub) EXPECT() *MockGitHubMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockGitHub) GetAuthenticatedUser ¶ added in v0.0.4
GetAuthenticatedUser mocks base method.
func (*MockGitHub) GetBaseURL ¶ added in v0.0.5
func (m *MockGitHub) GetBaseURL() string
GetBaseURL mocks base method.
func (*MockGitHub) GetBranchProtection ¶ added in v0.0.4
func (m *MockGitHub) GetBranchProtection(arg0 context.Context, arg1, arg2, arg3 string) (*github.Protection, error)
GetBranchProtection mocks base method.
func (*MockGitHub) GetCommit ¶ added in v0.0.9
func (m *MockGitHub) GetCommit(ctx context.Context, owner, repo, commitSHA string) (*github.Commit, error)
GetCommit mocks base method.
func (*MockGitHub) GetOwner ¶ added in v0.0.4
func (m *MockGitHub) GetOwner() string
GetOwner mocks base method.
func (*MockGitHub) GetPackageByName ¶ added in v0.0.4
func (m *MockGitHub) GetPackageByName(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) (*github.Package, error)
GetPackageByName mocks base method.
func (*MockGitHub) GetPackageVersionById ¶ added in v0.0.4
func (m *MockGitHub) GetPackageVersionById(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string, arg5 int64) (*github.PackageVersion, error)
GetPackageVersionById mocks base method.
func (*MockGitHub) GetPackageVersionByTag ¶ added in v0.0.4
func (m *MockGitHub) GetPackageVersionByTag(arg0 context.Context, arg1 bool, arg2, arg3, arg4, arg5 string) (*github.PackageVersion, error)
GetPackageVersionByTag mocks base method.
func (*MockGitHub) GetPackageVersions ¶ added in v0.0.4
func (m *MockGitHub) GetPackageVersions(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) ([]*github.PackageVersion, error)
GetPackageVersions mocks base method.
func (*MockGitHub) GetPullRequest ¶ added in v0.0.4
func (m *MockGitHub) GetPullRequest(arg0 context.Context, arg1, arg2 string, arg3 int) (*github.PullRequest, error)
GetPullRequest mocks base method.
func (*MockGitHub) GetRef ¶ added in v0.0.9
func (m *MockGitHub) GetRef(ctx context.Context, owner, repo, refString string) (*github.Reference, error)
GetRef mocks base method.
func (*MockGitHub) GetRepository ¶ added in v0.0.4
func (m *MockGitHub) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)
GetRepository mocks base method.
func (*MockGitHub) GetToken ¶ added in v0.0.4
func (m *MockGitHub) GetToken() string
GetToken mocks base method.
func (*MockGitHub) ListAllPackages ¶ added in v0.0.4
func (m *MockGitHub) ListAllPackages(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4, arg5 int) ([]*github.Package, error)
ListAllPackages mocks base method.
func (*MockGitHub) ListAllRepositories ¶ added in v0.0.4
func (m *MockGitHub) ListAllRepositories(arg0 context.Context, arg1 bool, arg2 string) ([]*github.Repository, error)
ListAllRepositories mocks base method.
func (*MockGitHub) ListFiles ¶ added in v0.0.4
func (m *MockGitHub) ListFiles(ctx context.Context, owner, repo string, prNumber, perPage, pageNumber int) ([]*github.CommitFile, *github.Response, error)
ListFiles mocks base method.
func (*MockGitHub) ListOrganizationRepsitories ¶ added in v0.0.7
func (m *MockGitHub) ListOrganizationRepsitories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
ListOrganizationRepsitories mocks base method.
func (*MockGitHub) ListPackagesByRepository ¶ added in v0.0.4
func (m *MockGitHub) ListPackagesByRepository(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4 int64, arg5, arg6 int) ([]*github.Package, error)
ListPackagesByRepository mocks base method.
func (*MockGitHub) ListPullRequests ¶ added in v0.0.9
func (m *MockGitHub) ListPullRequests(ctx context.Context, owner, repo string, opt *github.PullRequestListOptions) ([]*github.PullRequest, error)
ListPullRequests mocks base method.
func (*MockGitHub) ListReviews ¶ added in v0.0.4
func (m *MockGitHub) ListReviews(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.ListOptions) ([]*github.PullRequestReview, error)
ListReviews mocks base method.
func (*MockGitHub) ListUserRepositories ¶ added in v0.0.7
func (m *MockGitHub) ListUserRepositories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
ListUserRepositories mocks base method.
func (*MockGitHub) NewRequest ¶ added in v0.0.4
NewRequest mocks base method.
func (*MockGitHub) SetCommitStatus ¶ added in v0.0.4
func (m *MockGitHub) SetCommitStatus(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.RepoStatus) (*github.RepoStatus, error)
SetCommitStatus mocks base method.
func (*MockGitHub) UpdateBranchProtection ¶ added in v0.0.9
func (m *MockGitHub) UpdateBranchProtection(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.ProtectionRequest) error
UpdateBranchProtection mocks base method.
type MockGitHubMockRecorder ¶ added in v0.0.4
type MockGitHubMockRecorder struct {
// contains filtered or unexported fields
}
MockGitHubMockRecorder is the mock recorder for MockGitHub.
func (*MockGitHubMockRecorder) CloseSecurityAdvisory ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) CloseSecurityAdvisory(ctx, owner, repo, id interface{}) *gomock.Call
CloseSecurityAdvisory indicates an expected call of CloseSecurityAdvisory.
func (*MockGitHubMockRecorder) CreateBlob ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreateBlob(ctx, owner, repo, blob interface{}) *gomock.Call
CreateBlob indicates an expected call of CreateBlob.
func (*MockGitHubMockRecorder) CreateComment ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreateComment(ctx, owner, repo, number, comment interface{}) *gomock.Call
CreateComment indicates an expected call of CreateComment.
func (*MockGitHubMockRecorder) CreateCommit ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreateCommit(ctx, owner, repo, message, tree, parentSha interface{}) *gomock.Call
CreateCommit indicates an expected call of CreateCommit.
func (*MockGitHubMockRecorder) CreateHook ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) CreateHook(ctx, owner, repo, hook interface{}) *gomock.Call
CreateHook indicates an expected call of CreateHook.
func (*MockGitHubMockRecorder) CreatePullRequest ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreatePullRequest(ctx, owner, repo, title, body, head, base interface{}) *gomock.Call
CreatePullRequest indicates an expected call of CreatePullRequest.
func (*MockGitHubMockRecorder) CreateRef ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreateRef(ctx, owner, repo, ref, sha interface{}) *gomock.Call
CreateRef indicates an expected call of CreateRef.
func (*MockGitHubMockRecorder) CreateReview ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) CreateReview(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
CreateReview indicates an expected call of CreateReview.
func (*MockGitHubMockRecorder) CreateSecurityAdvisory ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) CreateSecurityAdvisory(ctx, owner, repo, severity, summary, description, v interface{}) *gomock.Call
CreateSecurityAdvisory indicates an expected call of CreateSecurityAdvisory.
func (*MockGitHubMockRecorder) CreateTree ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) CreateTree(ctx, owner, repo, base, entries interface{}) *gomock.Call
CreateTree indicates an expected call of CreateTree.
func (*MockGitHubMockRecorder) DeleteHook ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) DeleteHook(ctx, owner, repo, id interface{}) *gomock.Call
DeleteHook indicates an expected call of DeleteHook.
func (*MockGitHubMockRecorder) DismissReview ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) DismissReview(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
DismissReview indicates an expected call of DismissReview.
func (*MockGitHubMockRecorder) Do ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) Do(ctx, req interface{}) *gomock.Call
Do indicates an expected call of Do.
func (*MockGitHubMockRecorder) GetAuthenticatedUser ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetAuthenticatedUser(arg0 interface{}) *gomock.Call
GetAuthenticatedUser indicates an expected call of GetAuthenticatedUser.
func (*MockGitHubMockRecorder) GetBaseURL ¶ added in v0.0.5
func (mr *MockGitHubMockRecorder) GetBaseURL() *gomock.Call
GetBaseURL indicates an expected call of GetBaseURL.
func (*MockGitHubMockRecorder) GetBranchProtection ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetBranchProtection(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
GetBranchProtection indicates an expected call of GetBranchProtection.
func (*MockGitHubMockRecorder) GetCommit ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) GetCommit(ctx, owner, repo, commitSHA interface{}) *gomock.Call
GetCommit indicates an expected call of GetCommit.
func (*MockGitHubMockRecorder) GetOwner ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetOwner() *gomock.Call
GetOwner indicates an expected call of GetOwner.
func (*MockGitHubMockRecorder) GetPackageByName ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetPackageByName(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
GetPackageByName indicates an expected call of GetPackageByName.
func (*MockGitHubMockRecorder) GetPackageVersionById ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetPackageVersionById(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
GetPackageVersionById indicates an expected call of GetPackageVersionById.
func (*MockGitHubMockRecorder) GetPackageVersionByTag ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetPackageVersionByTag(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
GetPackageVersionByTag indicates an expected call of GetPackageVersionByTag.
func (*MockGitHubMockRecorder) GetPackageVersions ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetPackageVersions(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
GetPackageVersions indicates an expected call of GetPackageVersions.
func (*MockGitHubMockRecorder) GetPullRequest ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetPullRequest(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
GetPullRequest indicates an expected call of GetPullRequest.
func (*MockGitHubMockRecorder) GetRef ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) GetRef(ctx, owner, repo, refString interface{}) *gomock.Call
GetRef indicates an expected call of GetRef.
func (*MockGitHubMockRecorder) GetRepository ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetRepository(arg0, arg1, arg2 interface{}) *gomock.Call
GetRepository indicates an expected call of GetRepository.
func (*MockGitHubMockRecorder) GetToken ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
func (*MockGitHubMockRecorder) ListAllPackages ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) ListAllPackages(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
ListAllPackages indicates an expected call of ListAllPackages.
func (*MockGitHubMockRecorder) ListAllRepositories ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) ListAllRepositories(arg0, arg1, arg2 interface{}) *gomock.Call
ListAllRepositories indicates an expected call of ListAllRepositories.
func (*MockGitHubMockRecorder) ListFiles ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) ListFiles(ctx, owner, repo, prNumber, perPage, pageNumber interface{}) *gomock.Call
ListFiles indicates an expected call of ListFiles.
func (*MockGitHubMockRecorder) ListHooks ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) ListHooks(ctx, owner, repo interface{}) *gomock.Call
ListHooks indicates an expected call of ListHooks.
func (*MockGitHubMockRecorder) ListOrganizationRepsitories ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) ListOrganizationRepsitories(arg0, arg1 interface{}) *gomock.Call
ListOrganizationRepsitories indicates an expected call of ListOrganizationRepsitories.
func (*MockGitHubMockRecorder) ListPackagesByRepository ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) ListPackagesByRepository(arg0, arg1, arg2, arg3, arg4, arg5, arg6 interface{}) *gomock.Call
ListPackagesByRepository indicates an expected call of ListPackagesByRepository.
func (*MockGitHubMockRecorder) ListPullRequests ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) ListPullRequests(ctx, owner, repo, opt interface{}) *gomock.Call
ListPullRequests indicates an expected call of ListPullRequests.
func (*MockGitHubMockRecorder) ListReviews ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) ListReviews(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
ListReviews indicates an expected call of ListReviews.
func (*MockGitHubMockRecorder) ListUserRepositories ¶ added in v0.0.7
func (mr *MockGitHubMockRecorder) ListUserRepositories(arg0, arg1 interface{}) *gomock.Call
ListUserRepositories indicates an expected call of ListUserRepositories.
func (*MockGitHubMockRecorder) NewRequest ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) NewRequest(method, url, body interface{}) *gomock.Call
NewRequest indicates an expected call of NewRequest.
func (*MockGitHubMockRecorder) SetCommitStatus ¶ added in v0.0.4
func (mr *MockGitHubMockRecorder) SetCommitStatus(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
SetCommitStatus indicates an expected call of SetCommitStatus.
func (*MockGitHubMockRecorder) UpdateBranchProtection ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) UpdateBranchProtection(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
UpdateBranchProtection indicates an expected call of UpdateBranchProtection.
func (*MockGitHubMockRecorder) UpdateRef ¶ added in v0.0.9
func (mr *MockGitHubMockRecorder) UpdateRef(ctx, owner, repo, ref, sha, force interface{}) *gomock.Call
UpdateRef indicates an expected call of UpdateRef.
type MockGitMockRecorder ¶ added in v0.0.4
type MockGitMockRecorder struct {
// contains filtered or unexported fields
}
MockGitMockRecorder is the mock recorder for MockGit.
func (*MockGitMockRecorder) Clone ¶ added in v0.0.4
func (mr *MockGitMockRecorder) Clone(ctx, url, branch interface{}) *gomock.Call
Clone indicates an expected call of Clone.
func (*MockGitMockRecorder) GetToken ¶ added in v0.0.4
func (mr *MockGitMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
type MockProvider ¶ added in v0.0.4
type MockProvider struct {
// contains filtered or unexported fields
}
MockProvider is a mock of Provider interface.
func NewMockProvider ¶ added in v0.0.4
func NewMockProvider(ctrl *gomock.Controller) *MockProvider
NewMockProvider creates a new mock instance.
func (*MockProvider) EXPECT ¶ added in v0.0.4
func (m *MockProvider) EXPECT() *MockProviderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockProvider) GetToken ¶ added in v0.0.4
func (m *MockProvider) GetToken() string
GetToken mocks base method.
type MockProviderMockRecorder ¶ added in v0.0.4
type MockProviderMockRecorder struct {
// contains filtered or unexported fields
}
MockProviderMockRecorder is the mock recorder for MockProvider.
func (*MockProviderMockRecorder) GetToken ¶ added in v0.0.4
func (mr *MockProviderMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
type MockREST ¶ added in v0.0.4
type MockREST struct {
// contains filtered or unexported fields
}
MockREST is a mock of REST interface.
func NewMockREST ¶ added in v0.0.4
func NewMockREST(ctrl *gomock.Controller) *MockREST
NewMockREST creates a new mock instance.
func (*MockREST) EXPECT ¶ added in v0.0.4
func (m *MockREST) EXPECT() *MockRESTMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockREST) GetBaseURL ¶ added in v0.0.5
GetBaseURL mocks base method.
type MockRESTMockRecorder ¶ added in v0.0.4
type MockRESTMockRecorder struct {
// contains filtered or unexported fields
}
MockRESTMockRecorder is the mock recorder for MockREST.
func (*MockRESTMockRecorder) Do ¶ added in v0.0.4
func (mr *MockRESTMockRecorder) Do(ctx, req interface{}) *gomock.Call
Do indicates an expected call of Do.
func (*MockRESTMockRecorder) GetBaseURL ¶ added in v0.0.5
func (mr *MockRESTMockRecorder) GetBaseURL() *gomock.Call
GetBaseURL indicates an expected call of GetBaseURL.
func (*MockRESTMockRecorder) GetToken ¶ added in v0.0.4
func (mr *MockRESTMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
func (*MockRESTMockRecorder) NewRequest ¶ added in v0.0.4
func (mr *MockRESTMockRecorder) NewRequest(method, url, body interface{}) *gomock.Call
NewRequest indicates an expected call of NewRequest.
type MockRepoLister ¶ added in v0.0.7
type MockRepoLister struct {
// contains filtered or unexported fields
}
MockRepoLister is a mock of RepoLister interface.
func NewMockRepoLister ¶ added in v0.0.7
func NewMockRepoLister(ctrl *gomock.Controller) *MockRepoLister
NewMockRepoLister creates a new mock instance.
func (*MockRepoLister) EXPECT ¶ added in v0.0.7
func (m *MockRepoLister) EXPECT() *MockRepoListerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRepoLister) GetToken ¶ added in v0.0.7
func (m *MockRepoLister) GetToken() string
GetToken mocks base method.
func (*MockRepoLister) ListOrganizationRepsitories ¶ added in v0.0.7
func (m *MockRepoLister) ListOrganizationRepsitories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
ListOrganizationRepsitories mocks base method.
func (*MockRepoLister) ListUserRepositories ¶ added in v0.0.7
func (m *MockRepoLister) ListUserRepositories(arg0 context.Context, arg1 string) ([]*v1.Repository, error)
ListUserRepositories mocks base method.
type MockRepoListerMockRecorder ¶ added in v0.0.7
type MockRepoListerMockRecorder struct {
// contains filtered or unexported fields
}
MockRepoListerMockRecorder is the mock recorder for MockRepoLister.
func (*MockRepoListerMockRecorder) GetToken ¶ added in v0.0.7
func (mr *MockRepoListerMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
func (*MockRepoListerMockRecorder) ListOrganizationRepsitories ¶ added in v0.0.7
func (mr *MockRepoListerMockRecorder) ListOrganizationRepsitories(arg0, arg1 interface{}) *gomock.Call
ListOrganizationRepsitories indicates an expected call of ListOrganizationRepsitories.
func (*MockRepoListerMockRecorder) ListUserRepositories ¶ added in v0.0.7
func (mr *MockRepoListerMockRecorder) ListUserRepositories(arg0, arg1 interface{}) *gomock.Call
ListUserRepositories indicates an expected call of ListUserRepositories.