providers

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 6, 2023 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package providers contains general utilities for interacting with providers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildClient

func BuildClient(
	ctx context.Context,
	prov string,
	groupID int32,
	store db.Store,
) (ghclient.RestAPI, error)

BuildClient is a utility function which allows for building a client for a provider from a groupID and provider name.

TODO: This should return an abstract provider interface instead of a concrete github client.

Types

This section is empty.

Directories

Path Synopsis
Package github provides a client for interacting with the GitHub API
Package github provides a client for interacting with the GitHub API

Jump to