Documentation
¶
Overview ¶
Package errors provides errors for the evaluator engine
Index ¶
- Variables
- func IsRemediateFatalError(err error) bool
- func IsRemediateInformativeError(err error) bool
- func NewErrEvaluationFailed(sfmt string, args ...any) error
- func NewErrEvaluationSkipSilently(sfmt string, args ...any) error
- func NewErrEvaluationSkipped(sfmt string, args ...any) error
- func NewErrRemediationFailed(sfmt string, args ...any) error
Constants ¶
This section is empty.
Variables ¶
var ErrEvaluationFailed = errors.New("evaluation failure")
ErrEvaluationFailed is an error that occurs during evaluation of a rule.
var ErrEvaluationSkipSilently = errors.New("evaluation skipped silently")
ErrEvaluationSkipSilently specifies that the rule was evaluated but skipped silently.
var ErrEvaluationSkipped = errors.New("evaluation skipped")
ErrEvaluationSkipped specifies that the rule was evaluated but skipped.
var ErrRemediateFailed = errors.New("remediation failed")
ErrRemediateFailed is an error code that indicates that the remediation was attempted but failed.
var ErrRemediationNotAvailable = errors.New("remediation not available")
ErrRemediationNotAvailable is an error code that indicates that the remediation was not available for this rule_type
var ErrRemediationSkipped = errors.New("remediation not performed")
ErrRemediationSkipped is an error code that indicates that the remediation was not performed at all because the evaluation passed and the remediation was not needed.
Functions ¶
func IsRemediateFatalError ¶ added in v0.0.5
IsRemediateFatalError returns true if the error is a fatal error that should stop be reported to the user
func IsRemediateInformativeError ¶ added in v0.0.5
IsRemediateInformativeError returns true if the error is an informative error that should not be reported to the user
func NewErrEvaluationFailed ¶
NewErrEvaluationFailed creates a new evaluation error
func NewErrEvaluationSkipSilently ¶
NewErrEvaluationSkipSilently creates a new evaluation error
func NewErrEvaluationSkipped ¶
NewErrEvaluationSkipped creates a new evaluation error
func NewErrRemediationFailed ¶ added in v0.0.5
NewErrRemediationFailed creates a new remediation error
Types ¶
This section is empty.