errors

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2023 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package errors provides errors for the evaluator engine

Index

Constants

This section is empty.

Variables

var ErrEvaluationFailed = errors.New("evaluation failure")

ErrEvaluationFailed is an error that occurs during evaluation of a rule.

var ErrEvaluationSkipSilently = errors.New("evaluation skipped silently")

ErrEvaluationSkipSilently specifies that the rule was evaluated but skipped silently.

var ErrEvaluationSkipped = errors.New("evaluation skipped")

ErrEvaluationSkipped specifies that the rule was evaluated but skipped.

Functions

func NewErrEvaluationFailed

func NewErrEvaluationFailed(sfmt string, args ...any) error

NewErrEvaluationFailed creates a new evaluation error

func NewErrEvaluationSkipSilently

func NewErrEvaluationSkipSilently(sfmt string, args ...any) error

NewErrEvaluationSkipSilently creates a new evaluation error

func NewErrEvaluationSkipped

func NewErrEvaluationSkipped(sfmt string, args ...any) error

NewErrEvaluationSkipped creates a new evaluation error

Types

This section is empty.

Jump to