Documentation
¶
Overview ¶
Package errors provides errors for the evaluator engine
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrEvaluationFailed = errors.New("evaluation failure")
ErrEvaluationFailed is an error that occurs during evaluation of a rule.
var ErrEvaluationSkipSilently = errors.New("evaluation skipped silently")
ErrEvaluationSkipSilently specifies that the rule was evaluated but skipped silently.
var ErrEvaluationSkipped = errors.New("evaluation skipped")
ErrEvaluationSkipped specifies that the rule was evaluated but skipped.
Functions ¶
func NewErrEvaluationFailed ¶
NewErrEvaluationFailed creates a new evaluation error
func NewErrEvaluationSkipSilently ¶
NewErrEvaluationSkipSilently creates a new evaluation error
func NewErrEvaluationSkipped ¶
NewErrEvaluationSkipped creates a new evaluation error
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.