Documentation
¶
Overview ¶
Package interfaces provides necessary interfaces and implementations for implementing engine plugins
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ingester ¶
type Ingester interface {
// Ingest does the actual data ingestion for a rule type
Ingest(ctx context.Context, ent protoreflect.ProtoMessage, params map[string]any) (*Result, error)
}
Ingester is the interface for a rule type ingester
type RemediateActionOpt ¶ added in v0.0.5
type RemediateActionOpt int
RemediateActionOpt is the type that defines what action to take when remediating
const ( // ActionOptOn means perform the remediation ActionOptOn RemediateActionOpt = iota // ActionOptOff means do not perform the remediation ActionOptOff // ActionOptDryRun means perform a dry run of the remediation ActionOptDryRun // ActionOptUnknown means the action is unknown. This is a sentinel value. ActionOptUnknown )
func RemediationActionOptFromString ¶ added in v0.0.5
func RemediationActionOptFromString(s *string) RemediateActionOpt
RemediationActionOptFromString returns the RemediateActionOpt from a string representation
type Remediator ¶ added in v0.0.5
type Remediator interface {
Remediate(ctx context.Context, remAction RemediateActionOpt, ent protoreflect.ProtoMessage, pol map[string]any) error
}
Remediator is the interface for a rule type remediator
type Result ¶
type Result struct {
// Object is the object that was ingested. Normally comes from an external
// system like an HTTP server.
Object any
// Fs is the filesystem that was created as a result of the ingestion. This
// is normally used by the evaluator to do rule evaluation. The filesystem
// may be a git repo, or a memory filesystem.
Fs billy.Filesystem
}
Result is the result of an ingester
Click to show internal directories.
Click to hide internal directories.