Documentation
¶
Overview ¶
Package interfaces provides necessary interfaces and implementations for implementing engine plugins
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ingester ¶
type Ingester interface {
// Ingest does the actual data ingestion for a rule type
Ingest(ctx context.Context, ent protoreflect.ProtoMessage, params map[string]any) (*Result, error)
}
Ingester is the interface for a rule type ingester
type Result ¶
type Result struct {
// Object is the object that was ingested. Normally comes from an external
// system like an HTTP server.
Object any
// Fs is the filesystem that was created as a result of the ingestion. This
// is normally used by the evaluator to do rule evaluation. The filesystem
// may be a git repo, or a memory filesystem.
Fs billy.Filesystem
}
Result is the result of an ingester
Click to show internal directories.
Click to hide internal directories.