Documentation
¶
Overview ¶
Package mockgh is a generated GoMock package.
Index ¶
- type MockGraphQLAPI
- type MockGraphQLAPIMockRecorder
- type MockRestAPI
- func (m *MockRestAPI) CreateReview(arg0 context.Context, arg1, arg2 string, arg3 int, ...) (*github.PullRequestReview, error)
- func (m *MockRestAPI) DismissReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, ...) (*github.PullRequestReview, error)
- func (m *MockRestAPI) Do(ctx context.Context, req *http.Request, v any) (*github.Response, error)
- func (m *MockRestAPI) EXPECT() *MockRestAPIMockRecorder
- func (m *MockRestAPI) GetAuthenticatedUser(arg0 context.Context) (*github.User, error)
- func (m *MockRestAPI) GetBranchProtection(arg0 context.Context, arg1, arg2, arg3 string) (*github.Protection, error)
- func (m *MockRestAPI) GetOwner() string
- func (m *MockRestAPI) GetPackageByName(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) (*github.Package, error)
- func (m *MockRestAPI) GetPackageVersionById(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string, arg5 int64) (*github.PackageVersion, error)
- func (m *MockRestAPI) GetPackageVersionByTag(arg0 context.Context, arg1 bool, arg2, arg3, arg4, arg5 string) (*github.PackageVersion, error)
- func (m *MockRestAPI) GetPackageVersions(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) ([]*github.PackageVersion, error)
- func (m *MockRestAPI) GetPullRequest(arg0 context.Context, arg1, arg2 string, arg3 int) (*github.PullRequest, error)
- func (m *MockRestAPI) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)
- func (m *MockRestAPI) GetToken() string
- func (m *MockRestAPI) ListAllPackages(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4, arg5 int) (github0.PackageListResult, error)
- func (m *MockRestAPI) ListAllRepositories(arg0 context.Context, arg1 bool, arg2 string) (github0.RepositoryListResult, error)
- func (m *MockRestAPI) ListFiles(arg0 context.Context, arg1, arg2 string, arg3, arg4, arg5 int) ([]*github.CommitFile, error)
- func (m *MockRestAPI) ListPackagesByRepository(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4 int64, arg5, arg6 int) (github0.PackageListResult, error)
- func (m *MockRestAPI) ListReviews(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.ListOptions) ([]*github.PullRequestReview, error)
- func (m *MockRestAPI) NewRequest(method, urlStr string, body any, opts ...github.RequestOption) (*http.Request, error)
- func (m *MockRestAPI) SetCommitStatus(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.RepoStatus) (*github.RepoStatus, error)
- type MockRestAPIMockRecorder
- func (mr *MockRestAPIMockRecorder) CreateReview(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) DismissReview(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) Do(ctx, req, v interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetAuthenticatedUser(arg0 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetBranchProtection(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetOwner() *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetPackageByName(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetPackageVersionById(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetPackageVersionByTag(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetPackageVersions(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetPullRequest(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetRepository(arg0, arg1, arg2 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) GetToken() *gomock.Call
- func (mr *MockRestAPIMockRecorder) ListAllPackages(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) ListAllRepositories(arg0, arg1, arg2 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) ListFiles(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) ListPackagesByRepository(arg0, arg1, arg2, arg3, arg4, arg5, arg6 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) ListReviews(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) NewRequest(method, urlStr, body interface{}, opts ...interface{}) *gomock.Call
- func (mr *MockRestAPIMockRecorder) SetCommitStatus(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockGraphQLAPI ¶
type MockGraphQLAPI struct {
// contains filtered or unexported fields
}
MockGraphQLAPI is a mock of GraphQLAPI interface.
func NewMockGraphQLAPI ¶
func NewMockGraphQLAPI(ctrl *gomock.Controller) *MockGraphQLAPI
NewMockGraphQLAPI creates a new mock instance.
func (*MockGraphQLAPI) EXPECT ¶
func (m *MockGraphQLAPI) EXPECT() *MockGraphQLAPIMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockGraphQLAPIMockRecorder ¶
type MockGraphQLAPIMockRecorder struct {
// contains filtered or unexported fields
}
MockGraphQLAPIMockRecorder is the mock recorder for MockGraphQLAPI.
func (*MockGraphQLAPIMockRecorder) RunQuery ¶
func (mr *MockGraphQLAPIMockRecorder) RunQuery(ctx, query, variables interface{}) *gomock.Call
RunQuery indicates an expected call of RunQuery.
type MockRestAPI ¶
type MockRestAPI struct {
// contains filtered or unexported fields
}
MockRestAPI is a mock of RestAPI interface.
func NewMockRestAPI ¶
func NewMockRestAPI(ctrl *gomock.Controller) *MockRestAPI
NewMockRestAPI creates a new mock instance.
func (*MockRestAPI) CreateReview ¶
func (m *MockRestAPI) CreateReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.PullRequestReviewRequest) (*github.PullRequestReview, error)
CreateReview mocks base method.
func (*MockRestAPI) DismissReview ¶
func (m *MockRestAPI) DismissReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, arg5 *github.PullRequestReviewDismissalRequest) (*github.PullRequestReview, error)
DismissReview mocks base method.
func (*MockRestAPI) EXPECT ¶
func (m *MockRestAPI) EXPECT() *MockRestAPIMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRestAPI) GetAuthenticatedUser ¶
GetAuthenticatedUser mocks base method.
func (*MockRestAPI) GetBranchProtection ¶
func (m *MockRestAPI) GetBranchProtection(arg0 context.Context, arg1, arg2, arg3 string) (*github.Protection, error)
GetBranchProtection mocks base method.
func (*MockRestAPI) GetPackageByName ¶
func (m *MockRestAPI) GetPackageByName(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) (*github.Package, error)
GetPackageByName mocks base method.
func (*MockRestAPI) GetPackageVersionById ¶
func (m *MockRestAPI) GetPackageVersionById(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string, arg5 int64) (*github.PackageVersion, error)
GetPackageVersionById mocks base method.
func (*MockRestAPI) GetPackageVersionByTag ¶
func (m *MockRestAPI) GetPackageVersionByTag(arg0 context.Context, arg1 bool, arg2, arg3, arg4, arg5 string) (*github.PackageVersion, error)
GetPackageVersionByTag mocks base method.
func (*MockRestAPI) GetPackageVersions ¶
func (m *MockRestAPI) GetPackageVersions(arg0 context.Context, arg1 bool, arg2, arg3, arg4 string) ([]*github.PackageVersion, error)
GetPackageVersions mocks base method.
func (*MockRestAPI) GetPullRequest ¶
func (m *MockRestAPI) GetPullRequest(arg0 context.Context, arg1, arg2 string, arg3 int) (*github.PullRequest, error)
GetPullRequest mocks base method.
func (*MockRestAPI) GetRepository ¶
func (m *MockRestAPI) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)
GetRepository mocks base method.
func (*MockRestAPI) ListAllPackages ¶
func (m *MockRestAPI) ListAllPackages(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4, arg5 int) (github0.PackageListResult, error)
ListAllPackages mocks base method.
func (*MockRestAPI) ListAllRepositories ¶
func (m *MockRestAPI) ListAllRepositories(arg0 context.Context, arg1 bool, arg2 string) (github0.RepositoryListResult, error)
ListAllRepositories mocks base method.
func (*MockRestAPI) ListFiles ¶
func (m *MockRestAPI) ListFiles(arg0 context.Context, arg1, arg2 string, arg3, arg4, arg5 int) ([]*github.CommitFile, error)
ListFiles mocks base method.
func (*MockRestAPI) ListPackagesByRepository ¶
func (m *MockRestAPI) ListPackagesByRepository(arg0 context.Context, arg1 bool, arg2, arg3 string, arg4 int64, arg5, arg6 int) (github0.PackageListResult, error)
ListPackagesByRepository mocks base method.
func (*MockRestAPI) ListReviews ¶
func (m *MockRestAPI) ListReviews(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.ListOptions) ([]*github.PullRequestReview, error)
ListReviews mocks base method.
func (*MockRestAPI) NewRequest ¶
func (m *MockRestAPI) NewRequest(method, urlStr string, body any, opts ...github.RequestOption) (*http.Request, error)
NewRequest mocks base method.
func (*MockRestAPI) SetCommitStatus ¶
func (m *MockRestAPI) SetCommitStatus(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.RepoStatus) (*github.RepoStatus, error)
SetCommitStatus mocks base method.
type MockRestAPIMockRecorder ¶
type MockRestAPIMockRecorder struct {
// contains filtered or unexported fields
}
MockRestAPIMockRecorder is the mock recorder for MockRestAPI.
func (*MockRestAPIMockRecorder) CreateReview ¶
func (mr *MockRestAPIMockRecorder) CreateReview(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
CreateReview indicates an expected call of CreateReview.
func (*MockRestAPIMockRecorder) DismissReview ¶
func (mr *MockRestAPIMockRecorder) DismissReview(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
DismissReview indicates an expected call of DismissReview.
func (*MockRestAPIMockRecorder) Do ¶
func (mr *MockRestAPIMockRecorder) Do(ctx, req, v interface{}) *gomock.Call
Do indicates an expected call of Do.
func (*MockRestAPIMockRecorder) GetAuthenticatedUser ¶
func (mr *MockRestAPIMockRecorder) GetAuthenticatedUser(arg0 interface{}) *gomock.Call
GetAuthenticatedUser indicates an expected call of GetAuthenticatedUser.
func (*MockRestAPIMockRecorder) GetBranchProtection ¶
func (mr *MockRestAPIMockRecorder) GetBranchProtection(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
GetBranchProtection indicates an expected call of GetBranchProtection.
func (*MockRestAPIMockRecorder) GetOwner ¶
func (mr *MockRestAPIMockRecorder) GetOwner() *gomock.Call
GetOwner indicates an expected call of GetOwner.
func (*MockRestAPIMockRecorder) GetPackageByName ¶
func (mr *MockRestAPIMockRecorder) GetPackageByName(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
GetPackageByName indicates an expected call of GetPackageByName.
func (*MockRestAPIMockRecorder) GetPackageVersionById ¶
func (mr *MockRestAPIMockRecorder) GetPackageVersionById(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
GetPackageVersionById indicates an expected call of GetPackageVersionById.
func (*MockRestAPIMockRecorder) GetPackageVersionByTag ¶
func (mr *MockRestAPIMockRecorder) GetPackageVersionByTag(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
GetPackageVersionByTag indicates an expected call of GetPackageVersionByTag.
func (*MockRestAPIMockRecorder) GetPackageVersions ¶
func (mr *MockRestAPIMockRecorder) GetPackageVersions(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
GetPackageVersions indicates an expected call of GetPackageVersions.
func (*MockRestAPIMockRecorder) GetPullRequest ¶
func (mr *MockRestAPIMockRecorder) GetPullRequest(arg0, arg1, arg2, arg3 interface{}) *gomock.Call
GetPullRequest indicates an expected call of GetPullRequest.
func (*MockRestAPIMockRecorder) GetRepository ¶
func (mr *MockRestAPIMockRecorder) GetRepository(arg0, arg1, arg2 interface{}) *gomock.Call
GetRepository indicates an expected call of GetRepository.
func (*MockRestAPIMockRecorder) GetToken ¶
func (mr *MockRestAPIMockRecorder) GetToken() *gomock.Call
GetToken indicates an expected call of GetToken.
func (*MockRestAPIMockRecorder) ListAllPackages ¶
func (mr *MockRestAPIMockRecorder) ListAllPackages(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
ListAllPackages indicates an expected call of ListAllPackages.
func (*MockRestAPIMockRecorder) ListAllRepositories ¶
func (mr *MockRestAPIMockRecorder) ListAllRepositories(arg0, arg1, arg2 interface{}) *gomock.Call
ListAllRepositories indicates an expected call of ListAllRepositories.
func (*MockRestAPIMockRecorder) ListFiles ¶
func (mr *MockRestAPIMockRecorder) ListFiles(arg0, arg1, arg2, arg3, arg4, arg5 interface{}) *gomock.Call
ListFiles indicates an expected call of ListFiles.
func (*MockRestAPIMockRecorder) ListPackagesByRepository ¶
func (mr *MockRestAPIMockRecorder) ListPackagesByRepository(arg0, arg1, arg2, arg3, arg4, arg5, arg6 interface{}) *gomock.Call
ListPackagesByRepository indicates an expected call of ListPackagesByRepository.
func (*MockRestAPIMockRecorder) ListReviews ¶
func (mr *MockRestAPIMockRecorder) ListReviews(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
ListReviews indicates an expected call of ListReviews.
func (*MockRestAPIMockRecorder) NewRequest ¶
func (mr *MockRestAPIMockRecorder) NewRequest(method, urlStr, body interface{}, opts ...interface{}) *gomock.Call
NewRequest indicates an expected call of NewRequest.
func (*MockRestAPIMockRecorder) SetCommitStatus ¶
func (mr *MockRestAPIMockRecorder) SetCommitStatus(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call
SetCommitStatus indicates an expected call of SetCommitStatus.