Documentation
¶
Overview ¶
Package container provides a client for interacting with container images
Index ¶
- Variables
- func ExtractIdentityFromCertificate(manifest containerregistry.Manifest) (string, string, error)
- func GetImageManifest(imageRef name.Reference, username string, token string) (containerregistry.Manifest, error)
- func GetKeysFromVerified(verified []oci.Signature) ([]payload.SimpleContainerImage, error)
- func GetSignatureTag(imageRef name.Reference, username string, token string) (name.Reference, error)
- func ValidateSignature(ctx context.Context, accessToken string, package_owner string, ...) (*pb.SignatureVerification, *pb.GithubWorkflow, error)
- func VerifyFromIdentity(ctx context.Context, imageRef string, owner string, token string, ...) (bool, bool, map[string]interface{}, error)
Constants ¶
This section is empty.
Variables ¶
var REGISTRY = "ghcr.io"
REGISTRY is the default registry
Functions ¶
func ExtractIdentityFromCertificate ¶
func ExtractIdentityFromCertificate(manifest containerregistry.Manifest) (string, string, error)
ExtractIdentityFromCertificate returns the identity and issuer from the certificate
func GetImageManifest ¶
func GetImageManifest(imageRef name.Reference, username string, token string) (containerregistry.Manifest, error)
GetImageManifest returns the manifest for the given image
func GetKeysFromVerified ¶
func GetKeysFromVerified(verified []oci.Signature) ([]payload.SimpleContainerImage, error)
GetKeysFromVerified returns the keys from the verified signatures nolint: gocyclo
func GetSignatureTag ¶
func GetSignatureTag(imageRef name.Reference, username string, token string) (name.Reference, error)
GetSignatureTag returns the signature tag for a given image if exists
func ValidateSignature ¶
func ValidateSignature(ctx context.Context, accessToken string, package_owner string, package_url string) (*pb.SignatureVerification, *pb.GithubWorkflow, error)
ValidateSignature returns information about signature validation of a package
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.