Documentation
¶
Overview ¶
Package providers contains general utilities for interacting with providers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildClient ¶
func BuildClient( ctx context.Context, prov string, groupID int32, store db.Store, ) (ghclient.RestAPI, error)
BuildClient is a utility function which allows for building a client for a provider from a groupID and provider name.
TODO: This should return an abstract provider interface instead of a concrete github client.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.